<?php
// $Id: pe_assignment.pages.inc,v 1.11 2010/02/06 18:59:14 dakala Exp $

/**
* @file
*
*/

/**
 * Home page of assignments which will display a page depending on the user
 *
 * @global Object $user
 * @return String $output - The built page with select options form at the top
 * and a sortable list of assignments
 */
function pe_assignment_home() {
  global $user;

  $arg = $nids = array();
  $args = arg(1);

  if ($args != '') {
    $arg = explode(',', $args);
    $teacher_uid = $arg[1];
    $group_nid = $arg[0];
  }

  $manager = $admin = array();

  if ($teacher_uid > 0) {
    $admin[] = $teacher_uid;
  }
  else {
    if ($user->is_secretary) {
      $manager[] = $user->uid;
    }
    else if ($user->is_teacher) {
      $admin[] = $user->uid;
    }
    else if ($user->uid > 1) {
      $uid = $user->uid;
    }
  }

  // course group nodes
  $og_nids = _get_og_nids((array) NODE_TYPE_GROUP_COURSE, $admin, $manager, $uid);
  // assignment nodes
  $nids = _get_nodes(array(NODE_TYPE_ASSIGNMENT_QUESTION), 1, 0, 1);
  $total_nids = count($nids);

  $output = '';

  if ($total_nids > 0) {

    if (($user->is_student) || ($user->is_teacher)) {
      drupal_set_title(t('My Assignments'));
    }

    $output .= '<p>'. t('List of assignments') .'</p>';
    $output .= drupal_get_form('assignment_select_options_form', $teacher_uid, $group_nid, $og_nids);

    $courses = array(
        'fields' => array(
        NODE_TYPE_ASSIGNMENT_QUESTION => array('field_start_date', 'field_end_date'),
        ),
    );

    $dfields = _build_cck_sql($courses);

    $count_sql = $query = '';

    $select = " SELECT ";
    $select .= implode(", ", $dfields['selects']) ."";
    $select .= ", oga.group_nid, pe_group_course.title AS pe_group_course_title \n";

    $query .= " FROM (";
    $query .= implode(", ", $dfields['froms']) .", {node} pe_group_course";
    $query .= ") \n";
    $query .= implode("\n", $dfields['joins']) ."";
    $query .= " INNER JOIN {og_ancestry} oga ON (oga.nid = pe_assignment_question.nid) \n";
    $query .= " WHERE ";
    $query .= implode("\n AND ", $dfields['ands']) ." \n";
    $query .= " AND oga.group_nid = pe_group_course.nid \n";
    $query .= " AND pe_group_course.type = '%s' \n";

    $dfields['args'][] = NODE_TYPE_GROUP_COURSE;

    if ($total_nids > 0) {
      $query .= " AND pe_assignment_question.nid IN (". implode(',', $nids)  .") \n";
      $count_sql .= "SELECT COUNT(nid) FROM {node} WHERE nid IN (". implode(',', $nids)  .") \n";
    }
    else {
      if (sizeof($og_nids)) {
        $query .= " AND oga.group_nid IN (". implode(',', $og_nids) .") \n";
        $count_sql .= "SELECT COUNT(pe_assignment_question.nid) ". $query  ." \n";
      }
      else {
        $count_sql .= "SELECT COUNT(n.nid) FROM {node} n WHERE n.type = '". NODE_TYPE_ASSIGNMENT_QUESTION ."'";
      }
    }

    $query = $select . $query;

    $header = array(
        array('data' => t('#')),
        array('data' => t('Title'), 'field' => 'pe_assignment_question_title'),
        array('data' => t('Start'), 'field' => 'field_start_date'),
        array('data' => t('End'), 'field' => 'field_end_date'),
        array('data' => t('Teacher')),
        array('data' => t('Group'), 'field' => 'pe_group_course_title'),
        array('data' => t('Status')),
        array('data' => t('Operations')),
    );

    $rows = $answer_authors_uids = $answer_authors_in_group_uids = array();
    $tablesort = tablesort_sql($header);

    $show_count = variable_get('items_per_page', 100);
    $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $dfields['args']);

    $i = 0;
    while ($row = db_fetch_object($result)) {
    // staff
      $uids = _get_og_admin_by_nid($row->group_nid, 0);
      $account = user_load(array('uid' => $uids[0]));

      // status
      $status = '';
      $uid = ($user->is_student) ? $user->uid : 0;
      $answer_authors = _get_field_value_author('field_assignment_question_id', NODE_TYPE_ASSIGNMENT_ANSWER, $row->pe_assignment_question_nid, $uid = 0);

      if ($user->is_student) {
        $status = ($answer_authors[$user->uid] > 0) ? t('Y') : t('N');
      }
      else {
        $answer_authors_uids = array();
        foreach ($answer_authors as $key => $value) {
          $answer_authors_uids[] = $key;
        }

        $og_uids = _get_og_uids($row->group_nid, 1, 1, 0, 0, '', FALSE, FALSE);
        $answer_authors_in_og_uids = array_intersect($answer_authors_uids, $og_uids); // TODO: debug
        $status = sizeof($answer_authors_in_og_uids) .'/'. sizeof($og_uids);
      }

      // operations
      $assignment_que_ans = ($answer_authors[$user->uid] > 0) ? $answer_authors[$user->uid] : $row->pe_assignment_question_nid;

      $ops = '';
      $ops .= l(t('View'), 'node/'. $assignment_que_ans, array('title' => t('View') .' '. $row->pe_assignment_question_title));
      $ops .= '&nbsp;'. variable_get('links_sep_char', '&bull;') .'&nbsp;'; //TODO:
      $ops .= l(t('List'), 'assignment/list/'. $row->pe_assignment_question_nid .'/'. $row->group_nid .'/'. $user->uid, array('title' => 'List of assignment results'));

      $rows[] = array(
          array('data' => $i + 1, 'align' => 'center'),
          array('data' => l($row->pe_assignment_question_title, 'node/'. $row->pe_assignment_question_nid, array('title' => $row->pe_assignment_question_title))),
          array('data' => format_date(strtotime($row->field_start_date), 'medium')),
          array('data' => format_date(strtotime($row->field_end_date), 'medium')),
          array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
          array('data' => l($row->pe_group_course_title, 'node/'. $row->group_nid, array('title' => $row->pe_group_course_title))),
          array('data' => $status, 'align' => 'center'),
          array('data' => $ops, 'align' => 'center'),
      );
      $i++;
    }

    if ($i == 0) {
      $rows[] = array(array('data' => t('No assignments found.'), 'colspan' => count($header), 'align' => 'center'));
    }

    $output .= theme('table', $header, $rows);
    $output .= theme('pager', NULL, $show_count, 0);

  }
  else {
    $output .= "<p>". t("There are no assignments or course groups yet.") ."</p>";
  }

  return $output;
}

/**
 * Select options dropdown box for assignments on top of the assignment
 * home page
 *
 * @global <type> $user
 * @param <type> $form_state
 * @param <type> $teacher_uid
 * @param <type> $group_nid
 * @param <type> $nids
 * @return <type>
 */
function assignment_select_options_form(&$form_state, $teacher_uid, $group_nid, $nids) {
  global $user;

  $uids = _get_og_uids('assignment_select_options_form()', $nids, 1, 0, 1, 0, '', FALSE, FALSE);

  $form['filter'] = array(
      '#type' => 'fieldset',
      '#title'  => t('Filter options'),
      '#description'  => "<p>". t('Select from the following options.') ."</p>",
      '#collapsed'  => FALSE,
      '#collapsible'  => TRUE,
  );

  if (($user->uid == 1) || ($user->is_secretary)) {
    $uids = _get_og_admin_by_nid($nids, ($user->is_secretary) ? $user->uid : 0);

    $form['filter']['teacher_uid'] = array(
        '#type' => 'select',
        '#default_value' => $teacher_uid,
        '#title' => '',
        '#options' => _get_user_select_options($uids, '<'. t('all teachers') .'>'),
        '#attributes' => array('onchange' => "form.submit('assignment_select_options_form')"),
        '#prefix' => '<div class="container-inline">',
    );
  }

  // if user doesn't have any groups, good-bye
  $og_node_options = _get_og_node_options($nids, '<'. t('all groups') .'>');
  if (!sizeof($og_node_options)) {
    return array();
  }

  $form['filter']['group_nid'] = array(
      '#type' => 'select',
      '#default_value' => $group_nid,
      '#options' => $og_node_options,
  );

  if ((!$user->uid == 1) && (!$user->is_secretary)) {
    $form['filter']['group_nid']['#prefix'] = '<div class="container-inline">';
  }

  $form['filter']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Filter'),
      '#suffix' => '</div>',
  );

  $form['#submit'] = array('assignment_select_options_form_submit');

  return $form;
}


/**
 * Submission of the assignment select options form for filtering the list of
 * assignments to be displayed
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function assignment_select_options_form_submit($form, &$form_state) {
  drupal_goto('assignment/'. $form_state['values']['group_nid'] .','. $form_state['values']['teacher_uid']);
}


/**
 * List view of assignments
 *
 * @global <type> $user
 * @return <type>
 */
function pe_assignment_list() {
  global $user;

  $assignment = node_load(array('nid' => arg(2)));
  $og_nid = arg(3);

  if ($user->is_student) {
    $uids = array($user->uid);
  }
  else {
    $uids = _get_og_uids('pe_assignment_list()', array($og_nid));
  }

  $fprofiles = array(
      NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
  );

  $fprofileedus = array(
      NODE_TYPE_PROFILE_EDU => array('field_studentid'),
  );

  $fassignment = array(
      NODE_TYPE_ASSIGNMENT_ANSWER => array('field_marked', 'field_score', 'field_ip'),
  );

  $pefields = _get_profile_fields_sql($fprofiles);
  $pufields = _get_profile_fields_sql($fprofileedus);
  $pafields = _get_profile_fields_sql($fassignment);

  $select_sql = '';
  $select_sql .= "SELECT DISTINCT u.uid, u.name AS username, profile.nid, \n";
  $select_sql .= implode(', ', $pefields['selects']) .", \n";
  $select_sql .= implode(', ', $pufields['selects']) .", \n";
  $select_sql .= implode(', ', $pafields['selects']) .", \n";
  $select_sql .= " pe_assignment_answer.nid AS pe_assignment_answer_nid, pe_assignment_answer.created \n";
  $select_sql .= " FROM ({users} u ) \n";
  $select_sql .= " LEFT JOIN {node} profile ON (u.uid = profile.uid AND profile.type = '%s') \n";
  $select_sql .= implode("\n", $pefields['joins']) ." \n";
  $select_sql .= " LEFT JOIN {node} profileedu ON (u.uid = profileedu.uid AND profileedu.type = '%s') \n";
  $select_sql .= implode("\n", $pufields['joins']) ." \n";
  $select_sql .= " LEFT JOIN {node} pe_assignment_answer ON (u.uid = pe_assignment_answer.uid AND pe_assignment_answer.type = '%s') \n";
  $select_sql .= implode("\n", $pafields['joins']) ." \n";

  $where = '';
  if (sizeof($uids)) {
    $where .= " WHERE u.uid IN (". implode(',', $uids) .") \n";
  }
  $select_sql .= $where;

  $args = array(NODE_TYPE_PROFILE, NODE_TYPE_PROFILE_EDU, NODE_TYPE_ASSIGNMENT_ANSWER);

  $count_sql = "SELECT COUNT(*) FROM {users} u \n";
  $count_sql .= $where;

  $header = array(
      array('data' => t('#')),
      array('data' => t('Fullname'), 'field' => 'field_lastname'),
      array('data' => t('Gender'), 'field' => 'field_gender'),
      array('data' => t('Student ID'), 'field' => 'field_studentid'),
      array('data' => t('Points'), 'field' => 'field_score'),
      array('data' => t('Submitted'), 'field' => 'created'),
      array('data' => t('Marked'), 'field' => 'field_marked'),
      array('data' => t('Hostname'), 'field' => 'field_ip'),
      array('data' => t('Operations')),
  );

  $tablesort = tablesort_sql($header);

  $show_count = variable_get('items_per_page', 100);

  $result = pager_query($select_sql . $tablesort, $show_count, 0, $count_sql, $args);

  $rows = array();
  while ($node = db_fetch_object($result)) {
  // mock up user profile
    $account = new stdClass();
    $account->uid = $node->uid;
    $account->name = $node->username;
    $account->profile->field_lastname[0]['value'] = $node->field_lastname;
    $account->profile->field_firstname[0]['value'] = $node->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($node->field_personal_title);

    $points = '';
    $points .= ($node->field_marked > 0) ? $node->field_score .'/'. $assignment->field_max_score[0]['value'] : '?';
    $points .= (($node->field_marked > 0) && ($assignment->field_percent[0]['value'] == 'yes')) ?  ' ('. $node->field_score * 100 / $assignment->field_max_score[0]['value'] .'%)' : '';

    $ops = ($node->pe_assignment_answer_nid > 0) ? l(t('View'), 'node/'. $node->pe_assignment_answer_nid, array('title' => t('View'))) : '-';

    $rows[] = array(
        array('data' => $i + 1, 'align' => 'center'),
        array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
        array('data' => ($node->field_gender != '') ? theme('image', 'misc/icon_'. drupal_strtolower($node->field_gender) .'.gif')  : '--', 'align' => 'center'),
        array('data' => $node->field_studentid),
        array('data' => $points, 'align' => 'center'),
        array('data' => ($node->created > 0) ? (format_date($node->created, 'medium')) : '-', 'align' => 'center'),
        array('data' => ($node->field_marked > 0) ? (format_date($node->field_marked, 'small')) : '-', 'align' => 'center'),
        array('data' => ($node->field_ip != 0) ? $node->field_ip : '-', 'align' => 'center'),
        array('data' => $ops, 'align' => 'center'),
    );
    $i++;
  }
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No students available.'), 'colspan' => count($header), 'align' => 'center'));
  }

  drupal_set_title($assignment->title .' (<i>'. $assignment->og_groups_both[$og_nid] .'</i>)');

  $output = '';
  $output .= "<p>". t('Assignments list ...') ."</p>";
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);

  return $output;

}
