<?php
// $Id: pe_course.admin.inc,v 1.11 2009/05/31 08:41:18 dakala Exp $


/**
 * @file
 *
 */


/**
 *  Allocate a course to a teacher. This process also creates a group for the course and teacher.
 * The teacher is the administrator of the group.
 *
 * This first page lists all teachers for a course, the nid of which is read from the URL
 *
 * @ array $form
 *
 */
function pe_course_add_teacher() {

  $nid = arg(1);
  $node = node_load($nid);

  $gid = _get_og_by_name(TEACHERS_GROUP, NODE_TYPE_GROUP);
  
  $teacher_uids = _get_og_uids(array($gid));

  $uids = array();

  $sql = '';
  $sql .= " SELECT c.uid FROM {pe_course_list} c \n";
  $sql .= " WHERE c.nid = %d \n";
  $sql .= " AND c.uid IN (". implode(", ", $teacher_uids) .") \n";

  $args = array($nid);

  $result = db_query($sql, $args);
  while ($obj = db_fetch_object($result)) {
    $uids[] = $obj->uid;
  }

  $sql = '';
  if (count($uids) > 0) {
    $_SESSION['users']['plus'] = $uids;
    $sql .= _get_basic_user_info_sql();
    $sql .= " AND u1.uid IN (". implode(", ", $uids) .") \n";
  }

  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
  );

  $args = $rows = array();

  if (drupal_strlen($sql)) {
    $show_count = variable_get('items_per_page', 100);
    $tablesort = tablesort_sql($header);
    $rst = pager_query($sql . $tablesort, $show_count, 0, NULL, $args);

    $i = 0;
    while ($row = db_fetch_object($rst)) {
      // mock up user profile
      $account = new stdClass();
      $account->uid = $row->uid;
      $account->name = $row->name;
      $account->profile->field_lastname[0]['value'] = $row->field_lastname;
      $account->profile->field_firstname[0]['value'] = $row->field_firstname;
      $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);

      $rows[] = array(
        array('data' => $i + 1, 'align' => 'center'),
        array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
        array('data' => ($row->field_gender != '') ? theme('image', "misc/icon_". drupal_strtolower($row->field_gender) .".gif")  :  '--', 'align' => 'center')
      );
      $i++;
    }
  }

  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No teachers for this course yet.'), 'colspan' => count($header), 'align' => 'center'));
  }

  // group title, group type
  $og = _get_nid_from_title(TEACHERS_GROUP, NODE_TYPE_GROUP);

  $output = '';
  $output .= '<p>'. t('Add a new teacher for this course. A course group will also be automatically created for this teacher.') .'</p>';
  $output .= drupal_get_form('pe_user_autocomplete_form', $node);
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);

  return $output;
}


/**
 * Form for the autocompletion of teachers' full names when allocating a course.
 *
 * @param array $form_state
 *  parameters passed from the current state of the form
 * @param obect $node
 *  the course node
 * @ array $form
 * the form definition with the hidden in the "value" field
 *
 */
function pe_user_autocomplete_form(&$form_state, $node) {

  $form['node'] = array(
    '#type' => 'value',
    '#value'  => $node,
  );

  $form['uid'] = array(
    '#type' => 'textfield',
    '#autocomplete_path' => 'pe_user/autocomplete',
    '#size' => '30',
    '#prefix' => '<div class="container-inline">',
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Add a teacher'),
    '#suffix' => '</div>',
  );
}


/**
 * Autocomplete function for teachers' full names when the form is submitted. Also this is where
 * some validation of the form is done.
 *
 * @param array $form
 * @param array $form_state
 *
 */
function pe_user_autocomplete_form_submit($form, &$form_state) {

  $values = $form_state['values'];
  $course = $values['node'];

  $uid = $values['uid'];
  $values['uid'] = trim(substr($uid, strripos($uid, '-')+1));

  if ($values['uid'] < 1) {
    form_set_error('uid', t('A valid user is required.'));
    $error = 1;
  }
  else {
    $atid = $course->field_acad_term_id[0]['nid'];
    $acad_year_nid = _get_field_value($atid, 'field_acad_year_id', NODE_TYPE_ACAD_TERM);

    // update acad staff course list
    $rst = db_query("INSERT INTO {pe_course_list} (uid, nid, ayid) VALUES(%d, %d, %d)", $values['uid'], $course->nid, $acad_year_nid[$atid]);

    if (!$rst) {
      $error = 1;
      $msg = t('Could not initiate creation of new course group. No teacher-course assocation made.');
    }
    else {
      // create course group node managed by acad staff
      $edit = array();
      $edit['title'] = _format_course_group_title($course);
      $edit['body'] = t('Course group for teaching !course', array('!course' => $course->title));
      $edit['uid'] = $values['uid'];
      $edit['name'] = _get_name_from_uid($values['uid']);
      $edit['type'] = NODE_TYPE_GROUP_COURSE;
      $edit['created'] = time();
      $edit['changed'] = time() + 5000;
      $edit['comment'] = 0;
      $edit['sticky'] = 0;
      $edit['promoted'] = 0;
      $edit['taxonomy'] = array();
      // cck field
      $edit['field_course_id'][0]['nid'] = $course->nid;
      // og fields
      $edit['og_description'] = t('Course group,  %code', array('%code' => $course->field_code[0]['value']));
      $edit['og_selective'] = OG_CLOSED;
      $edit['og_directory'] = OG_DIRECTORY_ALWAYS;

      $node = (object)$edit;
      $node = node_submit($node);

      node_save($node);
      content_insert($node);

      if ($node->nid > 0) {
        $msg = t('New course group created.');
      } 
      else {
        $error = 1;
        $msg = t('Could not create the course group.');
      }
    }
  }
  
  $type = ($error) ? 'error' :  '';
  drupal_set_message($msg, $type);
}



/**
 * Configuration settings for the admin pages
 *
 * @ <type>
 */
function pe_course_admin_settings() {
  
  $form['notify'] = array(
    '#type' => 'fieldset',
    '#title'  => 'Notification flags',
    '#description'  => t('Turn on/off notification emails sent out to different people during the course registration process'),
    '#collapsible'  => TRUE,
    '#collapsed'  => TRUE,
  );

  $form['notify']['pe_course_registration_student_notify'] = array(
    '#type' => 'radios',
    '#title' => t('Notify students'),
    '#default_value' => variable_get('pe_course_registration_student_notify', 1),
    '#options' => array(1 => t('Yes'), 0 => t('No')),
    '#description' => t('<br />Do we notify students?'),
    '#prefix' => '<div class="container-inline-2">',
    '#suffix' => '</div>',
    );

  $form['notify']['pe_course_registration_adviser_notify'] = array(
    '#type' => 'radios',
    '#title' => t('Notify advisers'),
    '#default_value' => variable_get('pe_course_registration_adviser_notify', 1),
    '#options' => array(1 => t('Yes'), 0 => t('No')),
    '#description' => t('<br />Do we notify adivsers?'),
    '#prefix' => '<div class="container-inline-2">',
    '#suffix' => '</div>',
    );

  $form['notify']['pe_course_registration_officer_notify'] = array(
    '#type' => 'radios',
    '#title' => t('Notify faculty officer'),
    '#default_value' => variable_get('pe_course_registration_officer_notify', 1),
    '#options' => array(1 => t('Yes'), 0 => t('No')),
    '#description' => t('<br />Do we notify faculty officers?'),
    '#prefix' => '<div class="container-inline-2">',
    '#suffix' => '</div>',
    );

  $form['notify']['pe_course_registration_secretary_notify'] = array(
    '#type' => 'radios',
    '#title' => t('Notify secretaries'),
    '#default_value' => variable_get('pe_course_registration_secretary_notify', 1),
    '#options' => array(1 => t('Yes'), 0 => t('No')),
    '#description' => t('<br />Do we notify secretaries?'),
    '#prefix' => '<div class="container-inline-2">',
    '#suffix' => '</div>',
    );

  $form['email'] = array(
    '#type' => 'fieldset',
    '#title'  => 'Notification emails',
    '#description'  => t('Notification emails sent out during the course registration process'),
    '#collapsible'  => TRUE,
    '#collapsed'  => TRUE,
  );

  $form['email']['pe_course_wishlist_update_student_adviser_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Wishlist Update subject (Student > Adviser)'),
    '#default_value' => variable_get('pe_course_wishlist_update_student_adviser_subject', t('Course wishlist update')),
    '#description' => t('Subject of email sent out after wishlist update by a student.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_wishlist_update_student_adviser_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Wishlist Update body (Student > Adviser)'),
    '#default_value' => variable_get('pe_course_wishlist_update_student_adviser_body', t('!student (!program - !level level) has updated their wishlist.')),
    '#description' => t('Body of email sent out after wishlist update by a student.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_wishlist_update_officer_adviser_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Wishlist Update subject (Officer > Adviser)'),
    '#default_value' => variable_get('pe_course_wishlist_update_officer_adviser_subject', t('Course wishlist update')),
    '#description' => t('Subject of email sent out after wishlist update by a faculty officer.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_wishlist_update_officer_adviser_body'] = array(
    '#type' => 'textarea',
    '#title' =>  t('Course Wishlist Update body (Officer > Adviser)'),
    '#default_value' => variable_get('pe_course_wishlist_update_officer_adviser_body', t('!officer has updated course wishlist for !student (!program - !level level).')),
    '#description' => t('Subject of email sent out after wishlist update by a faculty officer.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_wishlist_update_officer_student_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Wishlist Update subject (Officer > Student)'),
    '#default_value' => variable_get('pe_course_wishlist_update_officer_student_subject', t('Course wishlist update')),
    '#description' => t('Subject of email sent out after wishlist update by a faculty officer.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_wishlist_update_officer_student_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Wishlist Update body (Officer > Student)'),
    '#default_value' => variable_get('pe_course_wishlist_update_officer_student_body', t('Your wishlist has been updated by !officer, your !officer_title.')),
    '#description' => t('Body of email sent out after wishlist update by a faculty officer.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_wishlist_update_adviser_officer_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Wishlist Update subject (Adviser > Officer)'),
    '#default_value' => variable_get('pe_course_wishlist_update_adviser_officer_subject', t('Course wishlist update')),
    '#description' => t('Subject of email messages sent out after wishlist update by adviser.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_wishlist_update_adviser_officer_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Wishlist Update body (Adviser > Officer)'),
    '#default_value' => variable_get('pe_course_wishlist_update_adviser_officer_body', t('Course wishlist for !student (!program - !level level) has been updated by !adviser.')),
    '#description' => t('Body of email messages sent out after wishlist update by adviser.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_wishlist_update_adviser_student_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Wishlist Update subject (Adviser > Student)'),
    '#default_value' => variable_get('pe_course_wishlist_update_adviser_student_subject', t('Course wishlist update')),
    '#description' => t('Subject of email messages sent out after wishlist update by adviser.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_wishlist_update_adviser_student_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Wishlist Update body (Adviser > Student)'),
    '#default_value' => variable_get('pe_course_wishlist_update_adviser_student_body', t('Your course wishlist has been updated by your !adviser_title. Please check. If you have any questions please contact the member of staff who updated your wishlist.')),
    '#description' => t('Body of email messages sent out after wishlist update by adviser.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_success_student_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration success subject (Student)'),
    '#default_value' => variable_get('pe_course_registration_success_student_subject', t('Course registration - success')),
    '#description' => t('Subject of email messages sent out after successful course registration.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_success_student_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration success body (Student)'),
    '#default_value' => variable_get('pe_course_registration_success_student_body', t('You have completed your course registration for !acad_year. These are the courses you have been registered for,  \n\n!course_list\n\nIf you have any questions please contact the !secretary_title.')),
    '#description' => t('Body of email messages sent out after successful course registration.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_success_adviser_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration success subject (Adviser)'),
    '#default_value' => variable_get('pe_course_registration_success_adviser_subject', t('Course registration - success')),
    '#description' => t('Subject of email messages sent out after successful course registration.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_success_adviser_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration success body (Adviser)'),
    '#default_value' => variable_get('pe_course_registration_success_adviser_body', t('Course registration for !student (!program - !level level) for !acad_year has been completed. These are the courses they have been registered for: \n\n!course_list.')),
    '#description' => t('Body of email messages sent out after successful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_success_officer_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration success subject (Officer)'),
    '#default_value' => variable_get('pe_course_registration_success_officer_subject', t('Course registration - success')),
    '#description' => t('Subject of email messages sent out after successful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_success_officer_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration success body (Officer)'),
    '#default_value' => variable_get('pe_course_registration_success_officer_body', t('Course registration for !student (!program - !level level) for !acad_year has been completed. These are the courses they have been registered for: \n\n!course_list.')),
    '#description' => t('Body of email messages sent out after successful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_success_secretary_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration success subject (Secretary)'),
    '#default_value' => variable_get('pe_course_registration_success_secretary_subject', t('Course registration - success')),
    '#description' => t('Subject of email messages sent out after successful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_success_secretary_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration success body (Secretary)'),
    '#default_value' => variable_get('pe_course_registration_success_secretary_body', t('Course registration for !student (!program - !level level) for !acad_year has been completed. These are the courses they have been registered for: \n\n!course_list.')),
    '#description' => t('Body of email messages sent out after successful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_failure_student_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration failure subject (Student)'),
    '#default_value' => variable_get('pe_course_registration_failure_student_subject', t('Course registration - failure')),
    '#description' => t('Subject of email messages sent out after unsuccessful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_failure_student_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration failure body (Student)'),
    '#default_value' => variable_get('pe_course_registration_failure_student_body', t('We are sorry to inform you that your course registration has failed and we have notified the appropriate members staff.')),
    '#description' => t('Body of email messages sent out after unsuccessful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_failure_adviser_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration failure subject (Adviser)'),
    '#default_value' => variable_get('pe_course_registration_failure_adviser_subject', t('Course registration - failure')),
    '#description' => t('Subject of email messages sent out after unsuccessful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_failure_adviser_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration failure body (Adviser)'),
    '#default_value' => variable_get('pe_course_registration_failure_adviser_body', t('Course registration for !student (!program - !level level) for !acad_year has failed due to some errors. This is for your attention.')),
    '#description' => t('Body of email messages sent out after unsuccessful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_failure_officer_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration failure subject (Officer)'),
    '#default_value' => variable_get('pe_course_registration_failure_officer_subject', t('Course registration - failure')),
    '#description' => t('Subject of email messages sent out after unsuccessful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_failure_officer_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration failure body (Officer)'),
    '#default_value' => variable_get('pe_course_registration_failure_officer_body', t('Course registration for !student (!program - !level level) for !acad_year has failed due to some errors. This is for your attention.')),
    '#description' => t('Body of email messages sent out after unsuccessful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  $form['email']['pe_course_registration_failure_secretary_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Course Registration failure subject (Secretary)'),
    '#default_value' => variable_get('pe_course_registration_failure_secretary_subject', t('Course registration - failure')),
    '#description' => t('Subject of email messages sent out after unsuccessful course registartion.'),
    '#size' => 60,
    '#maxlength' => 255,
  );

  $form['email']['pe_course_registration_failure_secretary_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Course Registration failure body (Secretary)'),
    '#default_value' => variable_get('pe_course_registration_failure_secretary_body', t('Course registration for !student (!program - !level level) for !acad_year has failed due to some errors. This is for your attention.')),
    '#description' => t('Body of email messages sent out after unsuccessful course registartion.'),
    '#cols' => 60,
    '#rows' => 5,
  );

  system_settings_form($form);
}


