<?php
// $Id: pe_course.pages.inc,v 1.21 2010/02/24 06:06:54 dakala Exp $

/**
 * @file
 *
 */


/**
 * Start page for course registration. Users are redirected to appropriate pages
 * based on their user status - student, course adviser, faculty officer, secretary
 * or super user
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_registration_home() {
  global $user;

  if(!isset($user->acad_year)) {
    $user = user_load($user->uid);
  }
  
  $acad_year = $user->acad_year;

  if (variable_get('do_registration', TRUE) != 1) {
    return t('No registration process.');
  }

  if (($acad_year->is_acad_registration_period) || ($acad_year->is_acad_registration_late)) {

    if ($acad_year->is_acad_registration_late) {
      drupal_set_message(t('Late registration.'));
    }

    if (($user->uid == 1) || ($user->is_secretary)) {
      $sec_uid = ($user->is_secretary) ? $user->uid : '';
      $output = _secretary_registration_home($sec_uid);
    } elseif ($user->is_faculty_officer) {
      drupal_goto('pe_course/registration/'. $user->uid);
    } elseif ($user->is_course_adviser) {
      $facor_uid = _get_og_admin_by_type(NODE_TYPE_GROUP_COURSE_ADVISERS, $user->uid);
      drupal_goto('pe_course/registration/'. $facor_uid .'/'. $user->uid);
    } elseif ($user->is_student) {
      if ((is_object($user->profileedu)) && (sizeof($user->profileedu->taxonomy))) {
        $cader_uid = _get_og_admin_by_type(NODE_TYPE_GROUP_COURSE_REGISTRATION, $user->uid);
        $facor_uid = _get_og_admin_by_type(NODE_TYPE_GROUP_COURSE_ADVISERS, $cader_uid);
        drupal_goto('pe_course/registration/'. $facor_uid .'/'. $cader_uid .'/'. $user->uid);
      } else {
        drupal_set_message(t('Your student profile has not been found. Without it you can not proceed with course registration.'));
        drupal_goto('user');
      }
    } else {
      drupal_goto('pe_programs');
    }
  } else {
    $output = ($acad_year->is_acad_registration_too_early) ? t('Registration has not started yet.') : t('Registration has closed.');
    return $output;
  }
  return $output;
}


/**
 * Start page for secretaries
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $secretary_uid
 * @return <type>
 */
function _secretary_registration_home($secretary_uid) {
  global $user, $conf;
  
  $breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = t('Course registration');
  drupal_set_breadcrumb($breadcrumb);

  $profiles = array(
    NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
  );

  $pfields = _get_profile_fields_sql($profiles);

  $query = '';
  $query .= "SELECT profile.nid, ou2.uid AS faculty_officer_uid, u1.name, COUNT(DISTINCT ou1.uid) AS total_advisers, COUNT(ou4.uid) AS total_students, \n";
  $query .= implode(', ', $pfields['selects']) ."\n";
  $query .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1, {node} n2) \n";
  $query .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $query .= " LEFT JOIN {og_uid} ou3 ON (ou1.uid = ou3.uid) \n";
  $query .= " LEFT JOIN {og_uid} ou4 ON (ou3.nid = ou4.nid) \n";
  $query .= implode("\n", $pfields['joins']) ." \n";
  $query .= " WHERE ou1.is_admin <> %d \n";
  $query .= " AND n1.type = '%s' \n";
  $query .= " AND n1.nid = ou1.nid \n";
  $query .= " AND ou2.is_admin = %d \n";
  $query .= " AND ou2.uid <> n1.uid \n";
  $query .= " AND n2.type = '%s' \n";
  $query .= " AND n2.nid = ou3.nid \n";
  $query .= " AND ou3.is_admin = %d \n";
  $query .= " AND ou4.is_admin <> %d \n";
  $query .= " AND profile.type = '%s' \n";
  $query .= " AND profile.uid = ou2.uid \n";
  $query .= " AND ou2.uid = u1.uid \n";

  // secretaries can only see their course advice groups
  // i.e. pe_group_adviser nodes they created
  if (($secretary_uid > 0) && ($user->uid > 1)) {
    $query .= " AND n1.uid = %d";
  }
  $query .= " GROUP BY ou2.uid, ou1.nid \n";

  $args = array();
  $args[] = 1;
  $args[] = NODE_TYPE_GROUP_COURSE_ADVISERS;
  $args[] = 1;
  $args[] = NODE_TYPE_GROUP_COURSE_REGISTRATION;
  $args[] = 1;
  $args[] = 1;
  $args[] = NODE_TYPE_PROFILE;

  if (($secretary_uid > 0) && ($user->uid > 1)) {
    $args[] = $secretary_uid;
  }

  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
    array('data' => t('Course advisers'), 'field' => 'total_advisers'),
    array('data' => t('Students'), 'field' => 'total_students'),
    array('data' => t('Operations')),
  );

  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);
  $result = pager_query($query . $tablesort, $show_count, 0, NULL, $args);

  $rows = array();
  $i = 0;
  while ($row = db_fetch_object($result)) {
    // mock up user profile
    $account = new stdClass();
    $account->uid = $row->faculty_officer_uid;
    $account->name = $row->name;
    $account->profile->field_lastname[0]['value'] = $row->field_lastname;
    $account->profile->field_firstname[0]['value'] = $row->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);

    $path = 'pe_course/registration/'. $row->faculty_officer_uid;
    $attributes = array('title' => t('View groups'));

    $rows[] = array(
      array('data' => $i + 1, 'align' => 'center'),
      array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
      array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
      array('data' => $row->total_advisers, 'align' => 'center'),
      array('data' => $row->total_students, 'align' => 'center'),
      array('data' => l(t('Details'), $path, array('attributes' => $attributes)), 'align' => 'center'),
    );
    $i++;
  }

  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No faculty officers found.'), 'colspan' => count($header), 'align' => 'center'));
  }

  $pager = theme('pager', NULL, $show_count, 0);
  
  $output .= '<p>' . t(variable_get('registration_faculty_officers_list_intro', 'Welcome to the Course Registration page. Below is a list of faculty officers and basic statistics of their course advisers and students.')) . '</p>';
  $output .= theme('table', $header, $rows);
  $output .= $pager;

  return $output;
}


/**
 * Start page for  faculty officers
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $faculty_officer
 * @return <type>
 */
function _officer_registration_home($faculty_officer) {
  global $user, $conf;

  $breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = t('Faculty officers');
  $breadcrumb = drupal_set_breadcrumb($breadcrumb);

  $gids = _get_og_nids((array) NODE_TYPE_GROUP_COURSE_ADVISERS, (array) $faculty_officer, $manager = array()); // course advice group nids
  $uids = _get_og_uids($gids); // course adviser uids

  $profiles = array(
    NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
  );
  
  $pfields = _get_profile_fields_sql($profiles);

  $db_info['field_section_id'] = _get_content_database_info('field_section_id', NODE_TYPE_PROFILE_EDU);
  $db_info['field_parent_section'] = _get_content_database_info('field_parent_section', NODE_TYPE_SECTION);

  $query = '';
  $query .= " SELECT profile.nid, ou2.uid AS course_adviser_uid, u1.name, COUNT(DISTINCT n1.nid) AS total_groups, COUNT(ou1.uid) AS total_students, n3.title AS section_title, n4.title AS parent_section_title, \n";
  $query .= implode(', ', $pfields['selects']) ."\n";
  $query .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1) \n";
  $query .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $query .= implode("\n", $pfields['joins']) ." \n";
  $query .= " INNER JOIN {node} n2 ON (profile.uid = n2.uid AND n2.type = '%s') \n";
  $query .= " INNER JOIN ". $db_info['field_section_id']['table'] ." ON (". $db_info['field_section_id']['table'] .".nid  = n2.nid)\n";
  $query .= " INNER JOIN {node} n3 ON (n3.nid = ". $db_info['field_section_id']['columns']['nid']['column'] .") \n";
  $query .= " INNER JOIN ". $db_info['field_parent_section']['table'] ." ON (". $db_info['field_parent_section']['table'] .".nid  = n3.nid)\n";
  $query .= " INNER JOIN {node} n4 ON (n4.nid = ". $db_info['field_parent_section']['columns']['nid']['column'] .") \n";

  $query .= " WHERE ou1.is_admin <> %d \n";
  $query .= " AND ou1.is_active = %d \n";
  $query .= " AND n1.type = '%s' \n";
  $query .= " AND n1.nid = ou1.nid \n";

  $query .= " AND ou2.is_admin = %d \n";
  $query .= " AND ou2.uid <> n1.uid \n";
  $query .= " AND ou2.uid = u1.uid \n";

  $query .= " AND profile.type = '%s' \n";
  $query .= " AND profile.uid = ou2.uid \n";

  // secretaries and faculty officers can only see their course advisers
  if (($user->is_secretary) || ($user->is_faculty_officer)) {
    $filter_uids = " AND ou2.uid  IN (". implode(', ', $uids) .") \n";
    $query .= $filter_uids;
  }
  else {
    $filter_uids = '';
  }

  $group_by = " GROUP BY ou2.uid, ou1.nid \n";
  $query .= $group_by;

  $args = array();
  $args[] = NODE_TYPE_PROFILE_EDU;
  $args[] = 1;
  $args[] = 1;
  $args[] = NODE_TYPE_GROUP_COURSE_REGISTRATION;
  $args[] = 1;
  $args[] = NODE_TYPE_PROFILE;

  $count_sql = '';
  $count_sql .= " SELECT COUNT(DISTINCT ou2.uid) \n";
  $count_sql .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1) \n";
  $count_sql .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $count_sql .= " WHERE ou1.is_admin <> %d \n";
  $count_sql .= " AND ou1.is_active = %d \n";
  $count_sql .= " AND n1.type = '%s' \n";
  $count_sql .= " AND n1.nid = ou1.nid \n";
  $count_sql .= " AND ou2.is_admin = %d \n";
  $count_sql .= " AND ou2.uid <> n1.uid \n";
  $count_sql .= " AND ou2.uid = u1.uid \n";
  $count_sql .= $filter_uids;
  $count_sql .= $group_by;

  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
    array('data' => t('Faculty'), 'field' => 'parent_section_title'),
    array('data' => t('Department'), 'field' => 'section_title'),
    array('data' => t('Groups'), 'field' => 'total_groups'),
    array('data' => t('Students'), 'field' => 'total_students'),
    array('data' => t('Operations')),
  );

  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);
  $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);

  $rows = array();
  $i = 0;
  while ($row = db_fetch_object($result)) {
    // mock up user profile
    $account = new stdClass();
    $account->uid = $row->course_adviser_uid;
    $account->name = $row->name;
    $account->profile->field_lastname[0]['value'] = $row->field_lastname;
    $account->profile->field_firstname[0]['value'] = $row->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);

    $path = 'pe_course/registration/'. arg(2) .'/'. $row->course_adviser_uid;
    $attributes = array('title' => t('View groups'));

    $rows[] = array(
      array('data' => $i + 1, 'align' => 'center'),
      array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
      array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
      array('data' => $row->parent_section_title),
      array('data' => $row->section_title),
      array('data' => $row->total_groups, 'align' => 'center'),
      array('data' => $row->total_students, 'align' => 'center'),
      array('data' => l(t('Details'), $path, array('attributes' => $attributes)), 'align' => 'center'),
    );
    $i++;
  }

  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No course advisers found.'), 'colspan' => count($header), 'align' => 'center'));
  }

  $pager = theme('pager', NULL, $show_count, 0);
  
  $output .= theme('table', $header, $rows);
  $output .= $pager;

  return $output;

}


/**
 * Start page for course advisers
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $course_adviser
 * @return <type>
 */
function _adviser_registration_home($course_adviser) {
  global $user, $conf;
  
//  $breadcrumb = drupal_get_breadcrumb();
//  if(user_access('administer nodes') || $user->is_secretary) {
//    $breadcrumb[] = l(t('Course registration'), 'pe_course/registration');
//    $breadcrumb[] = l(t('Faculty officers'), 'pe_course/registration/' . arg(2));
//  } 
//   
//  $breadcrumb[] = t('Course advisers');
//  drupal_set_breadcrumb($breadcrumb);

  $gids = _get_og_nids((array) NODE_TYPE_GROUP_COURSE_REGISTRATION, (array) $course_adviser); // course reg group nids
  
  $uids = array();
  
  $header = array(
      array('data' => t('#')),
      array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
      array('data' => t('Gender'), 'field' => 'field_gender'),
      array('data' => t('StudentID'), 'field' => 'field_studentid'),
      array('data' => t('Program'), 'field' => 'field_acad_program'),
      array('data' => t('Level'), 'field' => 'student_level'),
      array('data' => t('Operations')),
    );
    
  if(sizeof($gids)) {
  	$uids = _get_og_uids($gids); // student uids 
  
	  $db_info['field_credits'] = _get_content_database_info('field_credits', 'pe_course');
	
	  $profiles = array(
	    NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
	  );
	
	  $profileedus = array(
	    NODE_TYPE_PROFILE_EDU => array('field_studentid'),
	  );
	
	  $pfields = array();
	  $pfields[] = _get_profile_fields_sql($profiles);
	  $pfields[] = _get_profile_fields_sql($profileedus);
	
	  $query = '';
	  $query .= " SELECT profile.nid, u1.uid AS student_uid, u1.name, acad_program_table.title AS field_acad_program, \n";
	  $query .= " t.name AS student_level, COUNT(DISTINCT pending.nid) AS total_pending, COUNT(DISTINCT accepted.nid) AS total_accepted, COUNT(DISTINCT declined.nid) AS total_declined, \n";
	
	  for ($i = 0; $i < count($pfields); $i++) {
	    $query .= implode(', ', $pfields[$i]['selects']) ."";
	    $query .= ($i < (count($pfields)-1)) ? ", " : "";
	  }
	
	  $query .= "\n";
	  $query .= " FROM ({users} u1, {node} acad_program_table, {vocabulary} v) \n";
	  $query .= " INNER JOIN {node} profile ON (profile.uid = u1.uid) \n";
	  $query .= " INNER JOIN {node} profileedu ON (profileedu.uid = u1.uid) \n";
	  $query .= " LEFT JOIN {pe_course_wishlist} pending ON (pending.uid = u1.uid AND pending.status = ". PENDING ." AND pending.ayid = %d) \n";
	  $query .= " LEFT JOIN {pe_course_wishlist} accepted ON (accepted.uid = u1.uid AND accepted.status = ". ACCEPTED ." AND accepted.ayid = %d) \n";
	  $query .= " LEFT JOIN {pe_course_wishlist} declined ON (declined.uid = u1.uid AND declined.status = ". DECLINED ." AND declined.ayid = %d) \n";
	
	  for ($j = 0; $j < count($pfields); $j++) {
	    $query .= implode("\n", $pfields[$j]['joins']) ." \n";
	  }
	
	  $query .= " LEFT JOIN {content_field_acad_program_id} ON (content_field_acad_program_id.nid = profileedu.nid AND content_field_acad_program_id.field_acad_program_id_nid = acad_program_table.nid) \n";
	  $query .= " LEFT JOIN {term_data} t ON (v.vid = t.vid) \n";
	  $query .= " LEFT JOIN {term_node} tn ON (profileedu.nid = tn.nid AND tn.tid = t.tid) \n";
	  $query .= " WHERE profile.type = '%s' \n";
	  $query .= " AND profileedu.type = '%s' \n";
	  $query .= " AND v.name = '%s' \n";
	  $query .= " AND u1.uid  IN (". implode(', ', $uids) .") \n";
	  $query .= " GROUP BY u1.uid \n";
	
	  $args = array(
	    $user->acad_year->nid,
	    $user->acad_year->nid,
	    $user->acad_year->nid,
	    NODE_TYPE_PROFILE,
	    NODE_TYPE_PROFILE_EDU,
	    variable_get('student_level_vocab', t('Level'))
	    );
	    
	  $count_sql = _get_og_uids($gids, $is_active = 1, $no_admin_manager = 1, $no_manager = 0, $no_admin = 0, $orderby='ou.uid ASC', TRUE, TRUE);
	
	  $show_count = variable_get('items_per_page', 100);
	  $tablesort = tablesort_sql($header);
	  $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);
	
	  $rows = array();
	  $i = 0;
	  while ($row = db_fetch_object($result)) {
	    $student = user_load($row->student_uid);
	    $path = 'pe_course/registration/'. arg(2) .'/'. arg(3) .'/'. $row->student_uid;
	    $attributes = array('title' => t('View this student\'s courses'));
	
	    $rows[] = array(
	      array('data' => $i + 1, 'align' => 'center'),
	      array('data' => theme('username', $student, $link = 1, $access = 1, $path, $attributes)),
	      array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
	      array('data' => $row->field_studentid),
	      array('data' => $row->field_acad_program),
	      array('data' => $row->student_level),
	      array('data' => (count($student->course_list))
	      ? l(t('Courses list'), 'user/'. $student->uid, array('title' => t('List of courses for @ayear', array('@ayear' => $student->acad_year->title))))
	      : t('P') .'('. l($row->total_pending, $path .'/'. PENDING, array('title' => t('Pending'))) .')/'.
	      t('A') .'('. l($row->total_accepted, $path .'/'. ACCEPTED, array('title' => t('Accepted'))) .')/'.
	      t('D') .'('. l($row->total_declined, $path .'/'. DECLINED, array('title' => t('Declined'))) .')', 'align' => 'center'
	      ),
	    );
	    $i++;
	  }
	}
  
  if (count($uids) < 1) {
    $rows[] = array(array('data' => t('No students.'), 'colspan' => count($header), 'align' => 'center'));
  }

  $output = '';
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);

  return $output;
}


/**
 *
 * @global <type> $user
 * @param <type> $student_uid
 * @param <type> $course_status
 * @return <type>
 */
function _student_registration_home($student) {
  global $user;
  
  
  if($user->is_student) {
    $form['students-intro'] = array(
      '#type' => 'markup',
      '#value'  => '<p>' . t(variable_get('registration_student_courses_list_intro', 'Below is a list of your courses for the academic year. You may carry out any of the available operations on selected courses in your wishlist.')) . '</p>',
    );   
  }
    
  $program_id = $student->profileedu->field_acad_program_id[0]['nid'];
  $level_id = $student->profileedu->student_level_id;

  $nids = _get_program_courses($program_id, $level_id);

  if ((!$program_id > 0) && (!$level_id > 0)) {
    drupal_set_message(t('Incomplete criteria for finding student\'s courses.'), 'info');
  }

//  $course_status = ($course_status == '') ? '-1' : $course_status;
  $courses = array(
    'fields' => array(
      NODE_TYPE_COURSE => array('field_code', 'field_acad_term_id', 'field_credits'),
    ),
  );

  $dfields = _build_cck_sql($courses);

  $query = '';
  $query .= " SELECT DISTINCT pe_course.nid, pe_course.title AS course_title, ";
  $query .= implode(", ", $dfields['selects']) ." \n";
  $query .= ", SUBSTRING(node_content_type_pe_course.title, -2, 1) AS acad_term ";
  $query .= ", term_data_course_weight.name AS course_weight, term_data_course_weight.tid ";
  $query .= ", course_wishlist.locked, course_wishlist.status \n";
  $query .= " FROM (". implode(", ", $dfields['froms']) .") \n";
  $query .= " LEFT JOIN {term_node} term_node_course_weight ON (term_node_course_weight.nid = pe_course.nid) \n";
  $query .= " INNER JOIN {vocabulary} vocabulary_course_weight ON (vocabulary_course_weight.name = '%s') \n";
  $query .= " INNER JOIN {term_data} term_data_course_weight ON (term_data_course_weight.tid = term_node_course_weight.tid AND term_data_course_weight.vid = vocabulary_course_weight.vid) \n";
  $query .= " LEFT JOIN {pe_course_wishlist} course_wishlist ON (pe_course.nid = course_wishlist.nid AND course_wishlist.uid = %d) \n";
  $query .= implode("\n", $dfields['joins']) ." \n";
  $query .= " WHERE ";
  $query .= implode("\n AND ", $dfields['ands']) ." \n";

  if (count($nids) > 0) {
    $query .= " AND pe_course.nid IN (". implode(',', $nids) .") \n";
  }
  
  $args = array();
  $args[] = variable_get('course_weight_vocab', t('Course weight'));
  $args[] = $student->uid;

  if (count($dfields['args']) > 0) {
    $args = array_merge($args, $dfields['args']);
  }
  $status = arg(5);
  if((is_numeric($status)) && ($status >= 0)) {
  	$query .= " AND  course_wishlist.status = %d \n"; 
  	$args[] = $status;
  }
  
  $count_sql = "SELECT COUNT(*) FROM ($query) count_sql";
  
  // we need these headers for sorting of results
  $header = array(
    array('data' => t('Title'), 'field' => 'pe_course.title', 'sort' => 'asc'), //course_title
    array('data' => t('Code'), 'field' => 'field_code'),
    array('data' => t('Term'), 'field' => 'acad_term'),
    array('data' => t('Credits'), 'field' => 'field_credits'),
    array('data' => t('Weight'), 'field' => 'course_weight'),
    t('Status'),
    );
  
  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);
  $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);

  $destination = drupal_get_destination();

  $nodes = array();

  $total_credits = 0;
  
  while ($node = db_fetch_object($result)) {
    $nodes[$node->nid] = '';
    $form['title'][$node->nid] = array('#value' => l($node->course_title, 'node/'. $node->nid));
    $form['code'][$node->nid] =  array('#value' => $node->field_code);
    $form['acad_term'][$node->nid] = array('#value' => $node->acad_term);
    $form['credits'][$node->nid] =  array('#value' => $node->field_credits);
    $form['course_weight'][$node->nid] = array('#value' => $node->course_weight);
    $form[$node->nid]['course_status['. $node->nid .']'] = 
      ($node->locked)  ?
      array('#value' => _get_course_status($node->status)) :
      array(
        '#type' => 'select',
        '#default_value' => $node->status,
        '#options' => _course_status_options(),
        '#attributes' => array(
          'onchange' => "selectNode($node->nid)"
          )
        );

    $total_credits += ($node->status == ACCEPTED) ? $node->field_credits : 0;
  }

  // credits
  $credits = _get_min_max_credits($student->profileedu->field_acad_program_id[0]['nid'], $level_id);

  $min_max_credits = '';
  if ($credits['min'] > 0) {
    $min_max_credits .= $credits['min'];
  }

  if ($credits['max'] > 0) {
    $min_max_credits .= '/'. $credits['max'];
  }

  $form['total_credits'] = array(
    '#type' => 'value',
    '#value' => $total_credits
  );
  $form['acad_year_nid'] = array(
    '#type' => 'value',
    '#value' => $student->acad_year->nid
  );
  $form['acad_year_title'] = array(
    '#type' => 'value',
    '#value' => $student->acad_year->title
  );
  $form['min_max_credits'] = array(
    '#type' => 'value',
    '#value' => $min_max_credits
  );
  $form['is_registered'] = array(
    '#type' => 'value',
    '#value' => (count($student->course_list) > 0) ? 1 : 0
  );
  
  $form['wished'] = array(
    '#type' => 'value',
    '#value' => $wished
  );

  $form['student_uid'] = array(
    '#type' => 'value',
    '#value' => $student->uid
  );

  $form['nodes'] = array(
    '#type' => 'checkboxes',
    '#options' => $nodes,
    '#disabled' => $_SESSION[$student->uid]['is_registered']
  );

  $form['pager'] = array(
    '#type' => 'value',
    '#value' => theme('pager', NULL, $show_count, 0)
  );
  
  $form['header'] = array(
    '#type' => 'value',
    '#value' => $header
  );
  
  $form['#theme'] = 'student_registration_home';

  return $form;

}


/**
 * Select a faculty officer from a dropdown select box
 *
 * @param <type> $form_state
 * @param <type> $facors_group_admin
 * @return <type>
 */
function officer_select_options_form(&$form_state, $facors_group_admin) {

  $form['filter'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Faculty officers'),
    '#description'  => "<p>". t('Select a faculty officer from the list.') ."</p>",
    '#collapsed'  => FALSE,
    '#collapsible'  => TRUE,
    '#prefix' => '<div class="container-inline">',
    '#suffix' => '</div>',
  );

  $form['filter']['officer_uid'] = array(
    '#type' => 'select',
    '#default_value' => arg(2),
    '#title' => '',
    '#options' => _faculty_officer_options($facors_group_admin),
  );

  $form['filter']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Filter'),
  );

  $form['#submit'] = array('officer_select_options_form_submit');

  return $form;
}

/**
 * Select a course adviser from a dropdown select box
 *
 * @param <type> $form_state
 * @param <type> $default_officer_uid
 * @return <type>
 */
function adviser_select_options_form(&$form_state, $default_officer_uid) {
  $form['filter'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Course advisers'),
    '#description'  => "<p>". t('Select a course adviser from the list.') ."</p>",
    '#collapsed'  => FALSE,
    '#collapsible'  => TRUE,
    '#prefix' => '<div class="container-inline">',
    '#suffix' => '</div>',
  );

  $form['filter']['adviser_uid'] = array(
    '#type' => 'select',
    '#default_value' => arg(3),
    '#title' => '',
    '#options' => _course_adviser_options($default_officer_uid),    
    );

  $form['filter']['officer_uid'] = array(
    '#type' => 'hidden',
    '#value' => $default_officer_uid,
  );

  $form['filter']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Filter'),    
    );
  $form['#submit'] = array('adviser_select_options_form_submit');
  return $form;
}


/**
 * Select a student from a dropdown select box
 *
 * @global <type> $user
 * @param <type> $default_officer_uid
 * @return <type>
 */
function student_select_options_form($officer, $adviser) {
  global $user;

  if (!$user->is_student) {
  	
    $form['students-intro'] = array(
      '#type' => 'markup',
      '#value'  => '<p>' . t(variable_get('registration_students_list_intro', 'Below is a list of courses for the selected student. You may carry out any of the available operations on selected courses.')) . '</p>',
    );
      
    $form['students-filter'] = array(
      '#type' => 'fieldset',
      '#title'  => t('Students'),
      '#description'  => "<p>". t('Select a student for the active course adviser from the list.') ."</p>",
      '#collapsed'  => FALSE,
      '#collapsible'  => TRUE,
      '#prefix' => '<div class="container-inline">',
      '#suffix' => '</div>',
    );
    
    $form['students-filter']['student_uid'] = array(
      '#type' => 'select',
      '#default_value' => arg(4),
      '#title' => '',
      '#options' => _student_options($adviser->uid),
      );
    $form['students-filter']['status'] = array(
      '#type' => 'select',
      '#default_value' => arg(5),
      '#title' => '',
      '#options' => _course_status_options(),
      );

    $form['students-filter']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Filter'),
      '#submit' => array('students_filter_form_submit'),
      );
    }

    $form['officer_uid'] = array(
      '#type' => 'value',
      '#value' => $officer->uid,
    );

    $form['adviser_uid'] = array(
      '#type' => 'value',
      '#value' => $adviser->uid,
    );
  
    
  $form['action'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Operation'),
    '#collapsed'  => FALSE,
    '#collapsible'  => TRUE,
    '#prefix' => '<div class="container-inline">',
    '#suffix' => '</div>',
  );

  $options = array();
  foreach (pe_course_operations() as $operation => $array) {
    $options[$operation] = $array['label'];
  }

  $form['action']['operation'] = array(
    '#type' => 'select',
    '#default_value' => $_SESSION['op'],
    '#title' => '',
    '#options' => $options,
    );

  $form['action']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Operation'),
    '#submit' => array('pe_course_registration_operations_form_submit'),
    );

  $form['#theme'] = 'student_select_options_form';

  return $form;
}


/**
 * Theme students filter form.
 *
 * @ingroup themeable
 */
function theme_student_select_options_form($form) {
  $output = '';
  $output .= '<div id="node-admin-filter">';
  $output .= drupal_render($form['students-intro']);
  $output .= drupal_render($form['students-filter']);
  $output .= '</div>';
  $output .= drupal_render($form);
  return $output;
}


/**
 * Theme student registration home overview.
 *
 * @ingroup themeable
 */
function theme_student_registration_home($form) {
  global $user;

  $student_uid = $form['student_uid']['#value'];
  // If there are rows in this form, then $form['title'] contains a list of
  // the title form elements.
  $has_courses = isset($form['title']) && is_array($form['title']);

  $select_header = (($has_courses) && (!$_SESSION[$student_uid]['is_registered']) && ($form['wished']['#value'] != 1)) ? theme('table_select_header_cell') : '';
  
  $header = array($select_header);
  $header = array_merge($header, $form['header']['#value']);

  $status_options = _course_status_options();
  array_shift($status_options);

  $total_credits = 0;
  if ($has_courses) {
    foreach (element_children($form['title']) as $key) {
      $row = array();

      if (($user->is_student) && (in_array($form[$key]['course_status['. $key .']']['#value'], $status_options))) {
        $form['nodes'][$key]['#attributes']['disabled'] = 'disabled';
      }

      $row[] = drupal_render($form['nodes'][$key]);
      $row[] = drupal_render($form['title'][$key]);
      $row[] = drupal_render($form['code'][$key]);
      $row[] = drupal_render($form['acad_term'][$key]);
      $row[] = drupal_render($form['credits'][$key]);
      $row[] = drupal_render($form['course_weight'][$key]);

      if ($_SESSION[$student_uid]['is_registered']) {
        if (drupal_strlen($form[$key]['course_status['. $key .']']['#value']) > 0) {
          $row[] = drupal_render($form[$key]['course_status['. $key .']']);
        }
        else {
          $row[] = t('--');
          unset($form[$key]['course_status['. $key .']']);
        }
      }
      else {
        $row[] = drupal_render($form[$key]['course_status['. $key .']']);
      }
      
      $rows[] = $row;
    }
  }
  else {
    $rows[] = array(array('data' => t('No courses found.'), 'colspan' => count($header), 'align' => 'center'));
  }
  
  $output = '';
  $output .= '<p>'. t('Total credits: %total of %max', array('%total' => $form['total_credits']['#value'], '%max' => $form['min_max_credits']['#value'])) .'</p>';
  $output .= theme('table', $header, $rows);

  if ($form['pager']['#value']) {
    $output .= drupal_render($form['pager']);
  }

  $output .= drupal_render($form);

  return $output;
}


/**
 * Submit faculty officer select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function officer_select_options_form_submit($form, &$form_state) {
  $_SESSION['officer_uid'] = $form_state['values']['officer_uid'];
  drupal_goto('pe_course/registration/'. $form_state['values']['officer_uid']);
}

/**
 * Submit adviser select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function adviser_select_options_form_submit($form, &$form_state) {	
	$_SESSION['officer_uid'] = $form_state['values']['officer_uid'];
  $_SESSION['adviser_uid'] = $form_state['values']['adviser_uid'];
  drupal_goto('pe_course/registration/'. $form_state['values']['officer_uid'] .'/'. $form_state['values']['adviser_uid']);
}


/**
 * Submit student select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function student_select_options_form_submit($form, &$form_state) {
	$officer_uid = $form_state['values']['officer_uid'];
  $adviser_uid = $form_state['values']['adviser_uid'];
  $student_uid = $form_state['values']['student_uid'];
  drupal_goto('pe_course/registration/'. $officer_uid .'/'. $adviser_uid .'/'. $student_uid);
}


/**
 * Submit student filter select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function students_filter_form_submit($form, &$form_state) {
    if ($form_state['values']['op'] == t('Filter')) {
    	if ( (is_numeric($form_state['values']['officer_uid'])) && (is_numeric($form_state['values']['adviser_uid'])) && (is_numeric($form_state['clicked_button']['#post']['student_uid'])) ) {
        $tail = ($form_state['values']['status'] != '') ? '/' . $form_state['values']['status'] : '';    		
    		drupal_goto('pe_course/registration/'. $form_state['values']['officer_uid'] .'/'. $form_state['values']['adviser_uid'] .'/'. $form_state['clicked_button']['#post']['student_uid'] . $tail);
      } else {
        drupal_set_message(t('Incomplete criteria for finding a student.'), 'error');
        drupal_goto('pe_course/registration');
      }
    }
}


/**
 * Send email notifications to the student, course adviser and faculty officer about the
 * successfull course registration for the academic year
 *
 * @global <type> $op
 * @param <type> $student
 * @param <type> $language
 * @param <type> $params
 */
function _pe_course_mail_notify($op, $student, $language = NULL, $params) {
  global $user;
  
  $notify_student = variable_get('pe_course_registration_student_notify', TRUE);
  $notify_adviser = variable_get('pe_course_registration_adviser_notify', TRUE);
  $notify_officer = variable_get('pe_course_registration_officer_notify', TRUE);
  $notify_secretary = variable_get('pe_course_registration_secretary_notify', FALSE);

  $params['student'] = $student;
  $params['officer'] = ($user->is_faculty_officer) ? $user : user_load($params['officer_uid']);
  $params['adviser'] = user_load($params['adviser_uid']);

  if ($notify_student) {
    if (in_array($op, array('wishlist_update_officer', 'wishlist_update_adviser', 'registration_success', 'registration_failure'))) {
      $language = $language ? $language : user_preferred_language($student);
      $mail = drupal_mail('pe_course', 'pe_course_'. $op .'_student', $student, $language, $params);
      if ($mail) {
        watchdog($op, t('Sent %op notification email to %email', array('%op' => $op, '%email' => $student->mail)));
      }
    }
  }

  if ($notify_officer) {
    if (in_array($op, array('wishlist_update_adviser', 'registration_success', 'registration_failure'))) {
      $language = $language ? $language : user_preferred_language($officer);
      $mail = drupal_mail('pe_course', 'pe_course_'. $op .'_officer', $params['officer'], $language, $params);
      if ($mail) {
        watchdog($op, t('Sent %op notification email to %email', array('%op' => $op, '%email' => $officer->mail)));
      }
    }
  }

  if ($notify_adviser) {
    if (in_array($op, array('wishlist_update_student', 'wishlist_update_officer', 'registration_success', 'registration_failure'))) {
      $language = $language ? $language : user_preferred_language($adviser);
      $mail = drupal_mail('pe_course', 'pe_course_'. $op .'_adviser', $params['adviser'], $language, $params);
      if ($mail) {
        watchdog($op, t('Sent %op notification email to %email', array('%op' => $op, '%email' => $adviser->mail)));
      }
    }
  }

  // secretary is admin/author of pe_group_adviser node for the student's course adviser
  if ($notify_secretary) {
    if (in_array($op, array('registration_success', 'registration_failure'))) {
      foreach ($adviser->og_groups as $key => $og) {
        if ($og['type'] == NODE_TYPE_GROUP_COURSE_ADVISERS) {
          $og_nid = $og['nid'];
          break;
        }
      }

      if ($og_nid > 0) {
        $secretary_uid = _get_node_author($og_nid);
        $params['secretary'] = user_load($params['secretary_uid']);
      }

      $language = $language ? $language : user_preferred_language($secretary);
      $mail = drupal_mail('pe_course', 'pe_course_'. $op .'_secretary', $params['secretary'], $language, $params);
      if ($mail) {
        watchdog($op, t('Sent %op notification email to %email', array('%op' => $op, '%email' => $secretary->mail)));
      }
    }
  }
  return empty($mail) ? NULL : $mail['result'];
}


/**
 * Start page for faculty officers
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_officer_home($faculty_officer) {
  global $user;
  
  if(!isset($user->acad_year)) {
    $user = user_load($user->uid);
  }
  
  if (($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer)) {
    
    drupal_set_title(_format_fullnames($faculty_officer));
    
    $output = '';
    $output .= '<p>' . t(variable_get('registration_course_advisers_list_intro', 'Below is a list of Course advisers and basic statistics of their course advice groups and students.')) . '</p>';
  
    if (($user->uid == 1) || ($user->is_secretary)) {
      // facor groups are managed by secretaries
      $facors_group_admin = ($user->is_secretary) ? $user->is_secretary : '';
      $output .= drupal_get_form('officer_select_options_form', $facors_group_admin);
    }

    $output .= _officer_registration_home($faculty_officer->uid);

    return $output;
  }
  else {
    drupal_goto('pe_programs');
  }
}


/**
 * Start page for course advisers
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_adviser_home($faculty_officer, $course_adviser) {
  global $user;

  if(!isset($user->acad_year)) {
    $user = user_load($user->uid);
  }
  
  if (($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer) || ($user->is_course_adviser)) {
    
    drupal_set_title(_format_fullnames($course_adviser));
    
    $breadcrumb = drupal_get_breadcrumb();
    $breadcrumb[] = l(t('Course registration'), 'pe_course/registration');
    if(user_access('administer nodes') || $user->is_secretary || $user->is_faculty_officer) {  
        if(!$user->is_faculty_officer) {
            $breadcrumb[] = l(t('Faculty officers'), 'pe_course/registration/' . arg(2));
        }        
    }
    $breadcrumb[] = t('Course advisers');
    drupal_set_breadcrumb($breadcrumb);
    
    $output = '';
    
    if (($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer)) {
        $output .= '<p>' . t(variable_get('registration_students_list_intro', 'Below is a list of students for the selected Course adviser.')) . '</p>';
        $output .= drupal_get_form('adviser_select_options_form', $faculty_officer->uid);
    }
    
    $output .= _adviser_registration_home($course_adviser->uid);
    
    return $output;
  }
  else {
  	drupal_goto('pe_programs');
  }
}


/**
 * Start page for students
 *
 * @global <type> $user
 * @param <type> $form_state
 * @return <type>
 */
function pe_course_student_home($form_state, $officer, $adviser, $student) {
  global $user;
  
  if(!isset($user->acad_year)) {
    $user = user_load($user->uid);
  }
  
  $student_fullname = _format_fullnames($student);
  
  drupal_set_title($student_fullname);
  
  $breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = l(t('Course registration'), 'pe_course/registration');
    if(user_access('administer nodes') || $user->is_secretary || $user->is_faculty_officer) {  
        if(!$user->is_faculty_officer) {
            $breadcrumb[] = l(t('Faculty officers'), 'pe_course/registration/' . arg(2));
        }
        $breadcrumb[] = l(t('Course advisers'), 'pe_course/registration/' . arg(2) .'/' . arg(3));
    }
    
  $breadcrumb[] = $student_fullname;
  
  drupal_set_breadcrumb($breadcrumb);
    
  if(user_access('view course registration')) {  
      
    if (!$user->is_student) {
      $form['options'] = student_select_options_form($officer, $adviser);
    }
    
    $form['courses'] = _student_registration_home($student);
    
    // TODO:
    // Automatically select course when status changes
    // course-status[45] edit-course-status[45]
    //edit-nodes-45 edit-nodes-45
    drupal_add_js(drupal_get_path('module', 'pe_course') .'/pe_course.js', 'module');
    
    return $form; 

  }
  else {
    drupal_goto('pe_programs');
  }
}


/**
 * TODO:
 * 
 * List of courses for teachers & students
 *
 * @global <type> $user
 * @param <type> $account
 */
function pe_course_list($account) {
  global $user;

  if (($user->uid == 1) || ($account->is_student) || ($account->is_teacher)) {

  }
  else {
    drupal_set_message(t('List of all courses are here.'));
    drupal_goto('pe_programs/courses');
  }
}


/**
 * Theme student select dropdown box
 *
 * @param <type> $form
 * @return <type>
 */
//function theme_student_select_options_form($form) {
//  $output = '';
//  $output .= drupal_render($form);
//  return $output;
//}


/**
 * Get faculty officers for the select options dropdown box
 *
 * @global <type> $user
 * @param <type> $facors_group_admin
 * @return <type>
 */
function _faculty_officer_options($facors_group_admin) {
  global $user;

  $admin = array();
  $manager = ($facors_group_admin > 0) ? (array)$facors_group_admin : array();

  $officer_group_name = variable_get('officer_group_name', t('Faculty officers'));
  $officer_group_type = variable_get('officer_group_type', NODE_TYPE_GROUP);

  //$gid = _get_og_by_name($officer_group_name, $officer_group_type, $admin, $manager);
  $gid = _get_og_by_name($officer_group_name, $officer_group_type);
  $uids = _get_og_uids(array($gid));

  $officers = array();
  if (count($uids) > 0) {
    foreach ($uids as $uid) {
      $profile = user_load($uid);
      $officers[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }

  return $officers;
}


/**
 * Get course advisers in a course advice group managed by a faculty officer depending
 * on the user status for the select options dropdown box:
 *
 * su - <all course advisers> all cader groups
 * secretary - <my course advisers> Course adviser groups administered by my faculty officers
 *  - secretaries manage faculty officers > faculty officers manage course advice groups
 * faculty officer - <my course advisers>  course adviser groups they administer
 *
 * @global <type> $user
 * @param <type> $default_officer_uid
 * @return <type>
 */
function _course_adviser_options($default_officer_uid) {
  global $user;

  if ($user->is_secretary) {
    // secs manage facors > facors administer course advice groups
    $officer_group_name = variable_get('officer_group_name', t('Faculty officers'));
    $officer_group_type = variable_get('officer_group_type', NODE_TYPE_GROUP);

    $oficer_gids = _get_og_by_name($officer_group_name, $officer_group_type);
    $admin = _get_og_uids(array($oficer_gids));

  }
  elseif ($user->is_faculty_officer) {
    $admin = array($user->uid);
  }
  else {
    $admin = array();
  }
  $manager = array();
  $adviser_group_type = NODE_TYPE_GROUP_COURSE_ADVISERS;
  $gids = _get_og_nids((array)$adviser_group_type, $admin, $manager);
  $uids = _get_og_uids($gids);

  $advisers = array();
  if (count($uids) > 0) {
    foreach ($uids as $uid) {
      $profile = user_load($uid);
      $advisers[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }

  return $advisers;
}


/**
 * Get students in a registration group for the select options dropdown box
 *
 * @param <type> $adviser_uid
 * @return <type>
 */
function _student_options($adviser_uid) {
  
  $gids = _get_og_nids((array) NODE_TYPE_GROUP_COURSE_REGISTRATION, (array) $adviser_uid);
  $uids = _get_og_uids($gids);
  
  $students = array();
  if (count($uids) > 0) {
    foreach ($uids as $uid) {
      $profile = user_load($uid);
      $students[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }
  return $students;
}

/**
 * Course status options array maps constants to strings
 *
 * @return array
 */
function _course_status_options() {
  return array(
    -1  => '<'. t('N/A') .'>',
    PENDING => t('Pending'),
    ACCEPTED => t('Accepted'),
    DECLINED => t('Declined'),
  );
}

/**
 * Translate course status
 *
 * @param <type> $skey
 * @return <type>
 */
function _get_course_status($skey) {
  $skey = (drupal_strlen($skey) > 0) ? $skey : -1;
  $status = '';
  if ($skey == -1) {
    $status .= t('N/A');
  }
  else {
    $options = _course_status_options();
    foreach ($options as $key => $value) {
      if ($skey == $key) {
        $status .= $value;
      }
    }
  }
  return $status;
}



function pe_course_operations() {
	global $user;

	$operations = array();
	
	if (($user->uid == 1) || ($user->is_secretary) || ($user->is_course_adviser)  || ($user->is_faculty_officer)) {
		$operations = array_merge(
										$operations,
										array(
									    'status' => array(
									      'label' => t('Change status'),
									      'callback' => 'pe_course_mass_update',
									      'callback arguments' => array('updates' => array('status' => 1)),
									       )
									     )
									   );
									   
	   if(!$user->is_course_adviser) {
	     $operations = array_merge(
                    $operations,
                    array(
									    'lock' => array(
									      'label' => t('Lock courses'),
									      'callback' => 'pe_course_mass_update',
									      'callback arguments' => array('updates' => array('lock' => 1)),
										    ),
										    'unlock' => array(
										      'label' => t('Unlock courses'),
										      'callback' => 'pe_course_mass_update',
										      'callback arguments' => array('updates' => array('lock' => 0)),
										    ),
										    'confirm' => array(
										      'label' => t('Confirm courses'),
										      'callback' => 'pe_course_mass_update',
										      'callback arguments' => array('updates' => array('confirm' => 1)),
										    )
									    )
                     );
	   }
	}
	
	if (($user->uid == 1) || ($user->is_student)) {
		$operations = array_merge(
                    $operations,
                    array(
                      'add' => array(
                        'label' => t('Add to Wishlist'),
                        'callback' => 'pe_course_mass_update',
                        'callback arguments' => array('updates' => array('add' => 1)),
                        ),
                        'delete' => array(
                          'label' => t('Delete from Wishlist'),
                          'callback' => 'pe_course_mass_update',
                          'callback arguments' => array('updates' => array('add' => 0)),
                        )
                      )
                     );
	}
  
  return $operations;
}



function pe_course_mass_update($nodes, $updates, $form_state) {
  global $user;
    
    if (!user_access('view course registration')) {
      $error = 1;
      $message = t('You do not have permission to carry out this operation.');
    }
        
  if(sizeof($updates) && sizeof($nodes)) {
    foreach ($updates as $key => $val) {
			switch($key) {				
				case 'status':
					
					foreach($nodes as $nid) {
            // old
            $rst1 = db_query("UPDATE {pe_course_wishlist} SET status = %d, updated = %d WHERE uid = %d AND nid = %d AND ayid = %d", $form_state['values']['course_status'][$nid], time(), $form_state['values']['student_uid'], $nid,  $form_state['values']['acad_year_nid']);
            // new
            if ((db_affected_rows($rst1) == 0) && ($form_state['values']['course_status'][$nid] >= PENDING)) {
            	$rst2 = db_query("INSERT INTO {pe_course_wishlist} (uid, nid, ayid, status, locked, created, updated, confirmed) VALUES(%d, %d, %d, %d, %d, %d, %d, %d)", $form_state['values']['student_uid'], $nid, $form_state['values']['acad_year_nid'], $form_state['values']['course_status'][$nid], 0, time(), 0, 0);
            }
					}
					break;
					
				case 'lock':
				    
					foreach ($nodes as $node => $nid) {
					 $rst = db_query("UPDATE {pe_course_wishlist} SET locked = %d, confirmed = %d WHERE uid = %d AND ayid = %d", $val, time(), $form_state['values']['student_uid'], $form_state['values']['acad_year_nid']);
					}

            // wishlist update (lock) - officer
            $notify = 1;
            $op = "wishlist_update_officer";

            if (db_affected_rows($rst) > 0) {
              $message = t('You have updated the student\'s wishlist successfully: %total courses locked/unlocked.', array('%total' => count($nodes)));
            }
            else {
              $message = t('Wishlist update failed.');
            }
					
					break;
					
				case 'confirm':
					
					$min_max_credits = $form_state['values']['min_max_credits'];
					$total_credits = $form_state['values']['total_credits'];
					
					$credits = explode('/', $min_max_credits);
            if ($total_credits < $credits[0]) {
              $error = 1;
              $message = t('Too low total credits');
            } elseif (($credits[1] > 0) && ($total_credits > $credits[1])) {
              $error = 1;
              $message = t('Too high total credits');
            } else {
              $nids = array();
              // pe_course_wishlist - update
              foreach ($form_state['values']['course_status'] AS $nid => $status) {
                db_query("UPDATE {pe_course_wishlist} SET locked = %d, confirmed = %d WHERE uid = %d AND nid = %d AND ayid = %d", 1, time(), $form_state['values']['student_uid'], $nid, $form_state['values']['acad_year_nid']);
                // pe_course_list - insert
                if ($status == ACCEPTED) {
                  db_query("INSERT INTO {pe_course_list} (uid, nid, ayid) VALUES (%d, %d, %d)", $form_state['values']['student_uid'], $nid, $form_state['values']['acad_year_nid']);
                  $nids[] = $nid;
                }
              }
            }
            
            $notify = 1;
            $op = "wishlist_update_officer";
            
					break;
					
				case 'add':
					
			   if ($val == 1) {
            $rst1 = db_query("INSERT INTO {pe_course_wishlist} (uid, nid, ayid, status, locked, created, updated, confirmed) VALUES(%d, %d, %d, %d, %d, %d, %d, %d)", $form_state['values']['student_uid'], $nid, $user->acad_year->nid, $form_state['values']['course_status'][$nid], 0, time(), 0, 0);
          }
          elseif ($val == 0) {
            $rst2 = db_query("DELETE FROM {pe_course_wishlist} WHERE uid = %d AND ayid = %d AND status = %d", $form_state['values']['student_uid'], $user->acad_year->nid, PENDING);
          }
					
				  // wishlist update - student
	        $notify = 1;
	        $op = "wishlist_update_student";
	
	        if ((db_affected_rows($rst1) > 0) || (db_affected_rows($rst2) > 0)) {
	          $message = t('You have updated your wishlist successfully: %total courses added/updated.', array('%total' => count($nodes)));
	        }
	        else {
	          $message = t('Wishlist update failed.');
	        }
	        
			    // wishlist update - not student. who?
          if ($user->is_faculty_officer) {
            $who = "officer";
          } elseif ($user->is_course_adviser) {
            $who = "adviser";
          }

          $notify = 1;
          $op = "wishlist_update_". $who;

          if ((db_affected_rows($rst1) > 0) || (db_affected_rows($rst2) > 0)) {
            $message = t('You have updated the student\'s wishlist successfully: %total courses added/updated.', array('%total' => count($nodes)));
          }
          else {
            $message = t('Wishlist update failed.');
          }
          
					break;
			}
		}
	} else {
	    // nothing to do
	   $error = 1;
     $message = t('No valid operation selected.');    
	}
	
  // there can still be an error at the confirmation stage
  if (!$error) {

    $result = db_query('SELECT title FROM {node} WHERE nid IN(%d)', implode(',', array_keys($nodes)));
    
    while ($node = db_fetch_object($result)) {
      $courses[] = $node->title;
    }

    $op = "registration_success";
    $who = ($user->is_student && ($user->uid == $form_state['values']['student_uid'])) ? t('You have') : t('The student has');
    $message = t('%who been registered for %confirmed courses and %total credits for the %title academic year.', array('%who' => $who, '%confirmed' => theme('item_list', $courses), '%total' => $form_state['values']['total_credits'], '%title' => $form_state['values']['acad_year_title']));
    
  }
  else {
    $op = "registration_failure";
    $message = t('Sorry but the course registration was not successful.');
  }
	
	// send notification emails
  if ($notify) {
    $params = array();
    $params['student_uid'] = $form_state['values']['student_uid'];
    $params['adviser_uid'] = $form_state['values']['adviser_uid'];
    $params['officer_uid'] = $form_state['values']['officer_uid'];
    $params['courses'] = $courses;
    
    $student = user_load($params['student_uid']);

    $success = _pe_course_mail_notify($op, $student, NULL, $params);
    $message .= ($success) ? ' ' .t('Email notifications have been sent out.') : ' ' . t('Email notifications could not be sent.');
  }

  $type = ($error) ? 'error' : 'status';

  drupal_set_message($message, $type);
	
}

function pe_course_registration_operations_form_submit($form, &$form_state) {
	
  $operations = pe_course_operations();
  
  $operation = $operations[$form_state['values']['operation']];
  // Filter out unchecked nodes
  $nodes = array_filter($form_state['values']['nodes']);
  if ($function = $operation['callback']) {
    // Add in callback arguments if present.
    if (isset($operation['callback arguments'])) {
      $args = array_merge(array($nodes), $operation['callback arguments']);
    }
    else {
      $args = array($nodes);
    }
    $args[] = $form_state;
    call_user_func_array($function, $args);

    cache_clear_all();
  }
  else {
    // We need to rebuild the form to go to a second step.  For example, to
    // show the confirmation form for the deletion of nodes.
    $form_state['rebuild'] = TRUE;
  }
}

