<?php
// $Id: pe_edu.pages.inc,v 1.11 2010/02/24 06:06:54 dakala Exp $

/**
 * @file
 *
 */

/**
 * Autocomplete username and get full name output.
 * @param string $string
 * This returns lastname and surname for authorized users else username
 */
function pe_user_autocomplete($string = '') {

  $plus = $_SESSION['users']['plus'];
  $minus = $_SESSION['users']['minus'];

  $query = "SELECT uid, name FROM {users} WHERE LOWER(name) LIKE LOWER('%s%%')";

  if (count($plus) > 0) {
    $query .= " AND uid IN (". implode(',', $plus) .") \n";
  }
  if (count($minus) > 0) {
    $query .= " AND uid NOT IN (". implode(', ', $minus) .") \n";
  }

  $matches = array();
  if ($string) {
    $result = db_query_range($query, $string, 0, 10);
    while ($user = db_fetch_object($result)) {
      $object = user_load(array('uid' => $user->uid));
      $fullname = theme('username', $object, 0);
      $matches[$fullname .' - '. $user->uid] = $fullname;
    }
  }

  unset($_SESSION['users']['plus']);
  unset($_SESSION['users']['minus']);

  drupal_json($matches);
}


/**
 * List of users from the group membership page.
 *
 * @return $output
 *  page with list of users
 */
function pe_edu_userlist() {
	$filters = array();
  if (sizeof($_SESSION['pe_user_overview_filter'])) {
    foreach ($_SESSION['pe_user_overview_filter'] as $filter) {
      list($key, $value) = $filter;
      $filters[$key][] = $value;
    }
  }

//  drupal_set_title($title);

  $output = '';
  $output .= drupal_get_form('pe_edu_userlist_filter_form');
  $output .= _pe_edu_userlist_users($filters);

  return $output;
}

/**
 * Form builder; Return form for user administration filters.
 *
 * @ingroup forms
 * @see user_filter_form_submit()
 */
function pe_edu_userlist_filter_form() {
  $session = &$_SESSION['pe_user_overview_filter'];
  $session = is_array($session) ? $session : array();
  $filters = pe_edu_user_filters();

  $form['filters'] = array(
    '#type' => 'fieldset',
    '#title' => t('Show only users where'),
    '#theme' => 'pe_edu_user_filters',
  );

  $i = 0;
  foreach ($session as $filter) {
    list($type, $value) = $filter;
    // Merge an array of arrays into one if necessary.
    $options = $filters[$type]['options'];

//    if($type == 'level') {
//      $value = $options[$value]->option[$value+1];
//    } else {
//      $value = $options[$value];
//    }

    $params = array('%property' => $filters[$type]['title'] , '%value' => $options[$value]);
//    $params = array('%property' => $filters[$type]['title'], '%value' => $value);

    if ($i > 0) {
      $form['filters']['current'][] = array('#value' => t('<em>and</em> where <strong>%property</strong> is <strong>%value</strong>', $params));
    }
    else {
      $form['filters']['current'][] = array('#value' => t('<strong>%property</strong> is <strong>%value</strong>', $params));
    }

    $i++;
  }

  foreach ($filters as $key => $filter) {
    $names[$key] = $filter['title'];
    $form['filters']['status'][$key] = array(
      '#type' => 'select',
      '#options' => $filter['options'],
    );
  }

  $form['filters']['filter'] = array(
    '#type' => 'radios',
    '#options' => $names,
  );

  $form['filters']['buttons']['submit'] = array(
    '#type' => 'submit',
    '#value' => (count($session) ? t('Refine') : t('Filter')),
  );

  if (count($session)) {
    $form['filters']['buttons']['undo'] = array(
      '#type' => 'submit',
      '#value' => t('Undo'),
    );

    $form['filters']['buttons']['reset'] = array(
      '#type' => 'submit',
      '#value' => t('Reset'),
    );
  }

  drupal_add_js('misc/form.js', 'core');

  return $form;
}

/**
 * Process result from group membership administration filter form.
 */
function pe_edu_userlist_filter_form_submit($form, &$form_state) {
  $op = $form_state['values']['op'];
  $filters = pe_edu_user_filters();

  switch ($op) {
    case t('Filter'):
    case t('Refine'):
      if (isset($form_state['values']['filter'])) {
        $filter = $form_state['values']['filter'];
        // Merge an array of arrays into one if necessary.
        $options = $filters[$filter]['options'];

        if (isset($options[$form_state['values'][$filter]])) {
          $_SESSION['pe_user_overview_filter'][] = array($filter, $form_state['values'][$filter]);
        }
      }
      break;

    case t('Undo'):
      array_pop($_SESSION['pe_user_overview_filter']);
      break;

    case t('Reset'):
      $_SESSION['pe_user_overview_filter'] = array();
      break;

    case t('Update'):
      return;
  }

  $form_state['redirect'] = 'userlist';
  // TODO: return?
  return;
}





/**
 * Form builder; User administration page.
 *
 * @ingroup forms
 * @see user_admin_account_validate()
 * @see user_admin_account_submit()
 */
function _pe_edu_userlist_users($filters) {
    global $conf;

    $filter_roles = (array) $filters['role'];
    $filter_levels = (array) $filters['level'];
    $filter_sections = (array) $filters['section'];

    $header = array(
        array('data' => t('#')),
        array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
        array('data' => t('Gender'), 'field' => 'field_gender'),
        );

    $profileedu_fields = array('field_section_id');

    if (sizeof($filter_roles)) {
        if(in_array(PHPEDU_STUDENT_RID, $filter_roles)) {
            $profileedu_fields = array_merge($profileedu_fields, array('field_studentid', 'field_acad_program_id'));
            $header = array_merge($header, array(
                array('data' => t('Faculty/Dept.'), 'field' => 'field_section_id_title'),
                array('data' => t('StudentID'), 'field' => 'field_studentid'),
                array('data' => t('Level'), 'field' => 'field_level'),
                array('data' => t('Program'), 'field' => 'field_acad_program_id_title')
                ));
        }

        if(in_array(PHPEDU_ALUMNUS_RID, $filter_roles)) {
            $profileedu_fields = array_merge($profileedu_fields, array('field_acad_program_id', 'field_end_date'));
            $header = array_merge($header, array(
            array('data' => t('Faculty/Dept.'), 'field' => 'field_section_id_title'),
            array('data' => t('Program'), 'field' => 'field_acad_program_id_title'),
            array('data' => t('Grad. date'), 'field' => 'field_end_date')
            ));
        }

        if(in_array(array(PHPEDU_TEACHER_RID, PHPEDU_STAFF_RID), $filter_roles)) {
            $profileedu_fields = array_merge($profileedu_fields, array('field_position'));
            $header = array_merge($header, array(
              array('data' => t('Faculty/Dept.'), 'field' => 'field_section_id_title'),
              array('data' => t('Position'), 'field' => 'field_position')
            ));
        }
  } else {
      $header = array_merge($header, array(array('data' => t('Role'), 'field' => 'role')));
  }

  $fprofiles = array(
      NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
  );

  $fprofileedus = array(
      NODE_TYPE_PROFILE_EDU => $profileedu_fields,
  );

  $pefields = _get_profile_fields_sql($fprofiles);

  $select_sql = '';
  $select_sql .= "SELECT DISTINCT u.uid, u.name AS username,ur.rid AS role, profile.nid, \n";
  $select_sql .= implode(', ', $pefields['selects']) ."\n";

  if (sizeof($filters)) {

    $pufields = _get_profile_fields_sql($fprofileedus);

    $select_sql .= ", ";
    $select_sql .= implode(', ', $pufields['selects']) ." \n";
    $select_sql .= ", node_content_field_section_id.nid AS field_section_id, node_content_field_section_id.title AS field_section_id_title \n";
    if (in_array('field_acad_program_id', $profileedu_fields)) {
      $select_sql .= ", node_content_field_acad_program_id.nid AS field_acad_program_id, node_content_field_acad_program_id.title AS field_acad_program_id_title \n";
    }

    if(in_array(PHPEDU_STUDENT_RID, $filter_roles)) {
    	$select_sql .= ", profileedu.nid AS edunid, tn.tid AS tnnid, td.name AS field_level \n";
    }
  }

  $select_sql .= " FROM ({users} u ) \n";
  $select_sql .= " LEFT JOIN {users_roles} ur ON (ur.uid = u.uid) \n";
  $select_sql .= " LEFT JOIN {node} profile ON (u.uid = profile.uid AND profile.type = '%s') \n";
  $select_sql .= implode("\n", $pefields['joins']) ." \n";

  if (sizeof($filters)) {
    $select_sql .= " LEFT JOIN {node} profileedu ON (ur.uid = profileedu.uid AND profileedu.type = '%s') \n";
    $select_sql .= implode("\n", $pufields['joins']) ." \n";
    $select_sql .= " LEFT JOIN {node} node_content_field_section_id ON (content_field_section_id.field_section_id_nid = node_content_field_section_id.nid) \n";

    if (in_array('field_acad_program_id', $profileedu_fields)) {
      $select_sql .= " LEFT JOIN {node} node_content_field_acad_program_id ON (content_field_acad_program_id.field_acad_program_id_nid = node_content_field_acad_program_id.nid) \n";
    }

    // add profileedus tagged with terms for student level
    if(in_array(PHPEDU_STUDENT_RID, $filter_roles)) {
        $select_sql .= " LEFT JOIN {term_node} tn ON (tn.nid = profileedu.nid) \n";
        $select_sql .= " LEFT JOIN {term_data} td ON (td.tid = tn.tid) \n";
    }
  }

  $select_sql .= " WHERE u.uid > 1";

  $args = array(NODE_TYPE_PROFILE, NODE_TYPE_PROFILE_EDU);

  if (sizeof($filter_roles)) {
  	$select_sql .= "\n";
    $select_sql .=  " AND ur.rid = " . implode(' AND ur.rid = ', $filter_roles) . " \n";
  }

  if (sizeof($filter_sections)) {
    $select_sql .= "\n";
    $select_sql .=  " AND AND node_content_field_section_id.nid = " . implode(' AND AND node_content_field_section_id.nid = ', $filter_sections) . " \n";
  }

  if (sizeof($filter_levels)) {
    $select_sql .= "\n";
    $select_sql .=  " AND td.tid = " . implode(' AND td.tid = ', $filter_levels) . " \n";
  }

  $count_sql = " SELECT COUNT(DISTINCT u.uid) \n";
  $count_sql .= " FROM ({users} u) \n";
  $count_sql .= " LEFT JOIN {users_roles} ur ON (ur.uid = u.uid) \n";
  $count_sql .= " LEFT JOIN {role} r ON (r.rid = ur.rid) \n";
  $count_sql .= " LEFT JOIN {node} profile ON (ur.uid = profile.uid AND profile.type = '%s') \n";
  $count_sql .= implode("\n", $pefields['joins']) ." \n";
  $count_sql .= " WHERE u.uid > 1";

  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);
  $result = pager_query($select_sql . $tablesort, $show_count, 0, $count_sql, $args);

  $roles = user_roles(TRUE);
  $rows = array();
  $i = 0;
  while ($node = db_fetch_object($result)) {
    // mock up user profile
    $account = new stdClass();
    $account->uid = $node->uid;
    $account->name = $node->username;
    $account->profile->field_lastname[0]['value'] = $node->field_lastname;
    $account->profile->field_firstname[0]['value'] = $node->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($node->field_personal_title);

    $users_roles = array();
    $roles_result = db_query('SELECT rid FROM {users_roles} WHERE uid = %d', $account->uid);

    while ($user_role = db_fetch_object($roles_result)) {
      $users_roles[] = $roles[$user_role->rid];
    }

    asort($users_roles);
    $users_roles = (count($users_roles) >= 1) ? $users_roles : array('authenticated user');

    $row = array();
    $row[] = array('data' => $i + 1, 'align' => 'center');
    $row[] = array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes));
    $row[] = array('data' => ($node->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($node->field_gender) .'.gif')  : '--', 'align' => 'center');
    $row[] = array('data' => l($node->field_section_id_title, 'node/'. $node->field_section_id));

    if (in_array('field_studentid', $profileedu_fields)) {
      $row[] = array('data' => $node->field_studentid);
    }

    if (sizeof($filter_roles) && in_array(PHPEDU_STUDENT_RID, $filter_roles)) {
    	
      $row[] = array('data' => $node->field_level);
    }

    if (in_array('field_acad_program_id', $profileedu_fields)) {
      $row[] = array('data' => l($node->field_acad_program_id_title, 'node/'. $node->field_acad_program_id));
    }

    if (in_array('field_end_date', $profileedu_fields)) {
      $row[] = array('data' => $node->field_end_date);
    }

    if (in_array('field_position', $profileedu_fields)) {
      $row[] = array('data' => $node->field_position);
    }
    // add roles if no role filter
    if (sizeof($roles) < 1) {
      $row[] = array('data' => theme('item_list', $users_roles));
    }

    $rows[] = $row;

    $i++;
  }
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No people found.'), 'colspan' => count($header), 'align' => 'center'));
  }

  $output = '';
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);

  return $output;
}






/**
 * List group membership administration filters that can be applied.
 */
function pe_edu_user_filters() {
  // Regular filters
  $filters = array();
  $roles = user_roles(TRUE);
  unset($roles[DRUPAL_AUTHENTICATED_RID], $roles[PHPEDU_ADMINISTRATOR_RID]); // Don't list authorized role.
  if (count($roles)) {
    $filters['role'] = array(
      'title' => t('role'),
      'options' => $roles,
    );
  }
  $filters['section'] = array(
    'title' => drupal_strtolower(t('Section')),
    'options' => _get_nodes(array(NODE_TYPE_SECTION)),
  );


  foreach($_SESSION['pe_user_overview_filter'] as $filter) {
    if($filter[0] == 'role' && $filter[1] == PHPEDU_STUDENT_RID) {
      $levels = array();
      $vocab = variable_get('tax_student_levels', 'Level');
      $terms = _get_terms_for_vocabulary($vocab);

      foreach($terms as $term) {
        $option = $term->option;
        $tid = key($option);
        $levels[$tid] = $option[$tid];
      }

      $filters['level'] = array(
        'title' => drupal_strtolower(t('Level')),
        'options' => $levels,
      );
      break;
    }
  }

  return $filters;
}



/**
 * Theme user administration filter form.
 *
 * @ingroup themeable
 */
function theme_pe_edu_user_filter_form($form) {
  $output = '<div id="user-admin-filter">';
  $output .= drupal_render($form['filters']);
  $output .= '</div>';
  $output .= drupal_render($form);
  return $output;
}

/**
 * Theme user administration filter selector.
 *
 * @ingroup themeable
 */
function theme_pe_edu_user_filters($form) {
  $output = '<ul class="clear-block">';
  if (!empty($form['current'])) {
    foreach (element_children($form['current']) as $key) {
      $output .= '<li>'. drupal_render($form['current'][$key]) .'</li>';
    }
  }

  $output .= '<li><dl class="multiselect">'. (!empty($form['current']) ? '<dt><em>'. t('and') .'</em> '. t('where') .'</dt>' : '') .'<dd class="a">';
  foreach (element_children($form['filter']) as $key) {
    $output .= drupal_render($form['filter'][$key]);
  }
  $output .= '</dd>';

  $output .= '<dt>'. t('is') .'</dt><dd class="b">';

  foreach (element_children($form['status']) as $key) {
    $output .= drupal_render($form['status'][$key]);
  }
  $output .= '</dd>';

  $output .= '</dl>';
  $output .= '<div class="container-inline" id="user-admin-buttons">'. drupal_render($form['buttons']) .'</div>';
  $output .= '</li></ul>';

  return $output;
}