<?php
// $Id: pe_edu_helpers.inc,v 1.8 2010/02/24 06:06:54 dakala Exp $

/**
 * @file
 *
 */

/**
 * Home to helper functions to be included in pe_edu.module and made
 * available to the whole application
 *
 */

/**
 * Helper function to get a node title from its nid
 *
 * @param integer $nid
 *  unique nid of the node
 * @return string
 *  title of the node
 */
function _get_title_from_nid($nid) {
  $node = db_fetch_object(db_query("SELECT title FROM {node} WHERE nid = %d", $nid));
  return check_plain($node->title);
}

/**
 * Helper function to get the nid of a node from its title
 *
 * @param string $title
 *  the node title
 * @param string $type
 *  the node type
 * @return integer
 *  the nid of the node
 */
function _get_nid_from_title($title, $type) {
  $node = db_fetch_object(db_query("SELECT nid FROM {node} WHERE title = '%s' AND type = '%s'", $title, $type));
  return $node->nid;
}


/**
 * Helper function to get a username from a uid
 *
 * @param integer $uid
 *  unique id of the user
 * @return string
 *  username of the user
 */
function _get_name_from_uid($uid) {
  $obj = db_fetch_object(db_query("SELECT name FROM {users} WHERE uid = %d", $uid));
  return $obj->name;
}


/**
 * Helper function to get a user's uid of a node from a username
 *
 * @param string $username
 *  the username
 * @return integer
 *  the unique uid of the user
 */
function _get_uid_from_name($username) {
  $obj = db_fetch_object(db_query("SELECT uid FROM {users} WHERE name = '%s'", $username));
  return $obj->uid;
}

/**
 * Helper function to get the parent nid of a section
 *
 * @param integer $section
 *  nid of the section
 */
function _get_parent_section_nid($section) {
  $field_info = content_fields("field_parent_section");
  $db_info = content_database_info($field_info);
  $table = $db_info['table'];
  $column = $db_info['columns']['nid']['column'];

  $parent_section = db_fetch_object(db_query("SELECT `%s` FROM `%s` WHERE nid = %d", $column, $table, $section[0]['nid']));
  // if no parent, this is a possible parent
  $parent_nid = ($parent_section->$column > 0) ? $parent_section->$column : $section[0]['nid'];

  return $parent_nid;
}

/**
 * Get nid of group node
 *
 * @param <type> $name
 * @param <type> $type
 * @return <type>
 */
function _get_og_by_name($name, $type = NODE_TYPE_GROUP) {
  $node = db_fetch_object(db_query("SELECT nid FROM {node} WHERE LOWER(title) = '%s' AND type = '%s'", drupal_strtolower($name), $type));
  return $node->nid;
}


function _load_acad_year($datetime = '') {
  $now = time();
  $datetime = (drupal_strlen($datetime) > 0) ? $datetime : _timestamp_to_datetime($now);
  $start_field = 'field_start_date';
  $end_field = 'field_end_date';
  $start_info = _get_content_database_info($start_field, NODE_TYPE_ACAD_YEAR);
  $end_info = _get_content_database_info($end_field, NODE_TYPE_ACAD_YEAR);

  $start_table = $start_info['table'];
  $start_column = $start_info['columns']['value']['column'];

  $end_table = $end_info['table'];
  $end_column = $end_info['columns']['value']['column'];

  $query = "SELECT n.nid
            FROM ({node} n, %s)
            INNER JOIN `%s` ON (`%s`.nid = n.nid)
            WHERE `%s`.%s <= '%s'
            AND `%s`.%s >= '%s'
            AND n.nid = `%s`.nid
            AND n.type = '%s'";
  $args = array($start_table, $end_table, $end_table, $start_table, $start_column, $datetime, $end_table, $end_column, $datetime, $start_table, NODE_TYPE_ACAD_YEAR);
  $result = db_fetch_object(db_query($query, $args));

  // try again if we are on holiday
  if (!is_object($result)) {
    $query = "SELECT n.nid
            FROM ({node} n, %s)
            WHERE `%s`.%s > '%s'
            AND n.nid = `%s`.nid
            AND n.type = '%s'
            ORDER BY `%s`.%s DESC
            LIMIT %d";
    $args = array($end_table, $end_table, $end_column, $datetime, $end_table, NODE_TYPE_ACAD_YEAR, $end_table, $end_column, 1);
    $result = db_fetch_object(db_query($query, $args));
  }
  // default to the latest acad year in db
  if (!is_object($result)) {
    $query = "SELECT n.nid
            FROM ({node} n, %s)
            WHERE n.nid = `%s`.nid
            AND n.type = '%s'
            ORDER BY `%s`.%s DESC
            LIMIT %d";
    $args = array($end_table, $end_table, NODE_TYPE_ACAD_YEAR, $end_table, $end_column, 1);
    $result = db_fetch_object(db_query($query, $args));
  }

  $ayear_nid = $result->nid;

  if ($ayear_nid > 0) {
    $acad_year = node_load($ayear_nid);

    // acad terms
    $aterm_info = _get_content_database_info('field_acad_year_id', NODE_TYPE_ACAD_TERM);
    $aterm_table = $aterm_info['table'];
    $aterm_column = $aterm_info['columns']['nid']['column'];

    $tquery = "SELECT n.nid
              FROM {node} n, `%s`
              WHERE `%s`.%s = %d
              AND n.nid = `%s`.nid
              AND n.type = '%s'";

    $targs = array($aterm_table, $aterm_table, $aterm_column, $ayear_nid, $aterm_table, NODE_TYPE_ACAD_TERM);

    $tresult = db_query($tquery, $targs);

    $acad_terms = array();
    while ($trow = db_fetch_object($tresult)) {
      if (is_object($trow)) {
        $acad_year->acad_terms[] = node_load($trow->nid);
      }
    }
    //registration period
    $acad_year->is_acad_registration_period = $acad_year->is_acad_registration_late = $acad_year->is_acad_registration_too_late = $acad_year->is_acad_registration_too_early = 0;
    $acad_year->acad_registration = _get_registration_period($ayear_nid);

    // normal registration
    if ( ($now >= strtotime($acad_year->acad_registration->field_start_date[0]['value']))  && ($now <= strtotime($acad_year->acad_registration->field_end_date[0]['value'])) ) {
      $acad_year->is_acad_registration_period = 1;
    }
    // late registration
    if ( ($now >= strtotime($acad_year->acad_registration->field_end_date[0]['value']))  && ($now <= strtotime($acad_year->acad_registration->field_late_end_date[0]['value'])) ) {
      $acad_year->is_acad_registration_late = 1;
    }
    // too early to register
    if ($now < strtotime($acad_year->acad_registration->field_start_date[0]['value'])) {
      $acad_year->is_acad_registration_too_early = 1;
    }
    // too late to register
    if ($now > strtotime($acad_year->acad_registration->field_end_date[0]['value'])) {
      $acad_year->is_acad_registration_too_late = 1;
    }
  }
  else {
    $acad_year = '';
  }
  
  return $acad_year;
}


function _get_registration_period($ayear_nid = 0) {
  if ($ayear_nid < 1) {
    $ayear = _load_acad_year();
    $ayear_nid = $ayear->nid;
  }

  $regn_info = _get_content_database_info('field_acad_year_id', NODE_TYPE_ACAD_REGISTRATION);
  $table = $regn_info['table'];
  $column = $regn_info['columns']['nid']['column'];

  $query = "SELECT n.nid
            FROM {node} n, %s
            WHERE n.nid = `%s`.nid
            AND n.type = '%s'
            AND `%s`.%s = %d";
    $args = array($table, $table, NODE_TYPE_ACAD_REGISTRATION, $table, $column, $ayear_nid);
    $result = db_fetch_object(db_query($query, $args));
    if ($result->nid > 0) {
      return node_load($result->nid);
    }
    else {
      return '';
    }
}


/**
 * Get an array of nodes with nid as key and title as value. Useful when generating select options.
 *
 * @param string $type
 *  the node type
 * @param boolean $active
 *  the status of the node
 * @param integer $uid
 *  the uid of the node author
 * @return array
 */
function _get_node_options($type, $active = 1, $uid = 0) {

  $args = array();
  $query = "SELECT n.nid, n.title FROM {node} n \n";
  $query .= " WHERE n.type = '%s' \n";
  $args[] =$type;

  if ($active) {
    $query .= " AND n.status = %d \n";
    $args[] = 1;
  }
  if ($uid > 0) {
    $query .= " AND n.uid = %d \n";
    $args[] = $uid;
  }
  $query .= " ORDER BY n.title";

  $result = db_query($query, $args);

  $options = array();
  while ($row = db_fetch_object($result)) {
    $options[$row->nid] = $row->title;
  }
  return $options;
}


function _timestamp_to_datetime($timestamp = 0) {
  $timestamp = ($timestamp > 0) ? $timestamp : time();
  return date('Y-m-d\TH:i:s', $timestamp);
}


function _get_profile_fields_sql($profiles) {
  foreach ($profiles as $profile => $fields) {
    foreach ($fields as $field) {
      $db_info[$field] = _get_content_database_info($field, $profile);
    }

    foreach ($db_info as $field => $value) {
      $key = key($db_info[$field]['columns']);

      $raw_column = $db_info[$field]['columns'][$key]['column'];
      $pretty_column = substr($raw_column, 0, -(strlen($key)+1) );

      $pfields['selects'][] = $raw_column .' AS '. $pretty_column;
      $pfields['joins'][] = " LEFT JOIN {". $db_info[$field]['table'] ."} ON (". $db_info[$field]['table'] .".nid  = $profile.nid) ";
    }
  }

  return $pfields;
}

/**
 * Build sql statement for pulling out lastname, firsname, title, gender fields from users' profile
 *
 * @return string $query
 *
 */
function _get_basic_user_info_sql() {

  $profiles = array(
    NODE_TYPE_PROFILE => array('field_firstname', 'field_lastname', 'field_personal_title', 'field_gender'),
  );

  $pfields = _get_profile_fields_sql($profiles);

  $query = '';
  $query .= "SELECT u1.uid, u1.name, \n";
  $query .= implode(', ', $pfields['selects']) ."\n";
  $query .= " FROM ({users} u1, {node} profile) \n";
  $query .= implode("\n", $pfields['joins']) ." \n";
  $query .= " WHERE profile.type = 'profile' \n";
  $query .= " AND profile.uid = u1.uid \n";

  return $query;
}

/**
 * Get a role name from the db
 * @param integet $rid
 * @return string
 */
function _get_role_name($rid) {
  if ($rid > 0) {
  $object = db_fetch_object(db_query("SELECT name FROM {role} WHERE rid = %d", $rid));
  return $object->name;
  }
  else {
    return "";
  }
}


/**
 * Helper function to get a term name
 *
 * @param <type> $tid
 * @return <type>
 */
function _get_term_from_tid($tid) {
  $term = db_fetch_object(db_query("SELECT name FROM {term_data} WHERE tid = %d", $tid));
  $name = $term->name;
  return $name;
}


/**
 * Prints debug messages in a textarea. Pass an array, integer or string
 *
 * @param string, integer or array $str
 */
function _printrbox($str = '') {
  print("<br /><textarea cols='80' rows='20' style='font-weight: bold;'>");
  print_r($str);
  print("</textarea><br />");
}



/**
 * Helper function to help build SQL query statements for CCK data to get general profile information
 *
 * @param array $profiles
 *  an associative array.
 *  - key: profile node type
 *  - value: array of the field names
 * @param boolean $query
 *  This flag drives whether to return the full query string (TRUE) or an array
 *  holding table and field information for finishing the process of building the
 *  query elsewhere
 * @return array or string
 *   - array $pfields
     *  $pfields['selects']
     *  $pfields['froms']
     *  $pfields['joins']
 *  - string $query
 *
 */
function _build_cck_sql($profiles, $query = FALSE) {
  $i = 0;
  $done = FALSE;
  $args = array();
  foreach ($profiles['fields'] as $profile => $fields) {
    if ($i < 1) {
      $pfields['froms'][] = "{node} ". $profile;
      $profile1 = $profile;
    }
    else {
      if (!$done) {
        $pfields['joins'][] = " INNER JOIN {node} ". $profile ." ON(". $profile1 .".uid = ". $profile .".uid) ";
        $done = TRUE;
      }
    }

    $pfields['ands'][] = "". $profile .".type = '%s'";
    $args[] = $profile;

    $keys = array('nid', 'uid', 'value');
    foreach ($fields as $field) {
      $db_info[$field] = _get_content_database_info($field, $profile);

      $columns = $db_info[$field]['columns'];
      $total_columns = count($columns);

      if ($total_columns > 1) {
        for ($i=1; $i < $total_columns; $i++) {
          array_pop($columns);
        }
      }

      $key = key($columns);
      $raw_column = $db_info[$field]['columns'][$key]['column'];
      $pretty_column = substr($raw_column, 0, -(strlen($key)+1) );

      if ($key == 'nid') {
        // noderefs
        $table_alias = "node_". $db_info[$field]['table'];
        $new_pretty_column = $pretty_column ."_title";
        $pfields['selects'][] = "$table_alias.nid AS $pretty_column"; // TODO: debug
        $pfields['selects'][] = "$table_alias.title AS $new_pretty_column";
        $pfields['froms'][] = " {node} ". $table_alias ."";
        $pfields['joins'][] = " INNER JOIN {". $db_info[$field]['table'] ."} ON (". $db_info[$field]['table'] .".nid = $profile.nid AND ". $db_info[$field]['table'] .".". $raw_column ." = ". $table_alias .".nid) ";
        //$joined = TRUE;
      }
      elseif ($key == 'uid') {
        // userrefs
        $table_alias = "users_". $db_info[$field]['table'];
        $new_pretty_column = $pretty_column ."_name";
        $pfields['selects'][] = "$table_alias.name AS $new_pretty_column";
        $pfields['froms'][] = " {users} ". $table_alias ."";
        $pfields['joins'][] = " INNER JOIN {". $db_info[$field]['table'] ."} ON (". $db_info[$field]['table'] .".uid = $profile.uid AND ". $db_info[$field]['table'] .".". $raw_column ." = ". $table_alias .".uid) ";
      }
      else {
        $table_alias = $db_info[$field]['table'] ."_". $raw_column;
        $pfields['selects'][] = $table_alias .".". $raw_column ." AS ". $pretty_column;
        $pfields['joins'][] = " INNER JOIN {". $db_info[$field]['table'] ."} ". $table_alias ." ON (". $table_alias .".nid  = $profile.nid) ";
      }
    }
    $i++;
  }

  if (!$query) {
    $pfields['args'] = $args;
    return $pfields;
  }
  else {
    $sqlfrags = array();
    $sqlfrags[] = $pfields;

    $query = '';
    $query .= " SELECT ";
    for ($i = 0; $i < count($sqlfrags); $i++) {
      $query .= implode(", ", $sqlfrags[$i]['selects']) ."";
    }
    $query .= "\n";
    $query .= " FROM (";
    for ($j = 0; $j < count($sqlfrags); $j++) {
      $query .= implode(", ", $sqlfrags[$j]['froms']) ."";
    }
    $query .= ") \n";
    for ($k = 0; $k < count($sqlfrags); $k++) {
      $query .= implode("\n", $sqlfrags[$k]['joins']) ."";
    }
    $query .= "\n";
    $query .= " WHERE ";
    for ($l = 0; $l < count($sqlfrags); $l++) {
      $query .= implode("\n AND ", $sqlfrags[$l]['ands']) ."";
    }

    $sql = array();
    $sql['query'] = $query;
    $sql['args'] = $args;

    return $sql;
  }
}

//SELECT ou.uid FROM og_uid ou WHERE ou.is_active = 1 AND ou.nid IN () AND ou.is_admin < 1 AND ou.uid > 1 ORDER BY ou.uid ASC
function _get_og_uids($nids = NULL, $is_active = 1, $no_admin_manager = 1, $no_manager = 0, $no_admin = 0, $orderby='ou.uid ASC', $count = FALSE, $sql = FALSE) {

 $nids = (!is_array($nids)) ? array($nids) : $nids;

  $order = '';
  if ($count) {
    $fields = 'COUNT(*)';
  }
  else {
    $fields = "ou.uid";
    if ($orderby) {
      $order = "ORDER BY $orderby";
    }
  }

  $query = '';
  if (($no_admin == 0) && ($no_manager == 0)) {

    $query .= " SELECT $fields  \n";
    $query .= " FROM {og_uid} ou \n";
    $query .= " WHERE ou.is_active = $is_active \n";

    if ((isset($nids)) && (count($nids) > 0)) {
      $query .= " AND ou.nid IN (". implode(", ", $nids) .") \n";
    }

    if ($no_admin_manager) {
      $query .= " AND ou.is_admin < 1 \n";
    }
  }
  else {
    $query .= " SELECT $fields  \n";
    $query .= " FROM {og_uid} ou, {node} n \n";
    $query .= " WHERE ou.is_active = $is_active \n";
    $query .= " AND ou.nid = n.nid \n";

    if (count($nids) > 0) {
      $query .= " AND ou.nid IN (". implode(", ", $nids) .") \n";
    }

    if ($no_manager) {
      $query .= " AND ou.uid <> n.uid \n";
    }

    if ($no_admin) {
      $query .= " AND ou.is_admin < 1 \n";
    }
  }
  // no super user
  $query .= " AND ou.uid > 1 \n";
  $query .= " $order \n";

  if ($count) {
    if ($sql) {
      return $query;
    }
    else {
      // TODO: debug
      $uids = db_fetch_object(db_query($query));
    }
  }
  else {
    $result = db_query($query);

    $uids = array();
    while ($row = db_fetch_object($result)) {
      $uids[] = $row->uid;
    }
    return $uids;
  }
}


function _get_og_nids($type = array('pe_group'), $admin = array(), $manager = array()) {
  $args = array();
  $query = '';
  $query .= " SELECT DISTINCT n.nid \n";
  $query .= " FROM {node} n, {og_uid} ou \n";
  $query .= " WHERE n.type IN ('". implode("', '", $type) ."') \n";
  $query .= " AND n.nid = ou.nid \n";

  if (count($manager) > 0) {
    $query .= " AND n.uid IN (". implode(", ", $manager) .") \n";
    $query .= " AND ou.is_admin = %d \n";
    $args[] = 1;
  }
  elseif (count($admin) > 0) {
    $query .= " AND ou.uid IN (". implode(", ", $admin) .") \n";
    $query .= " AND ou.is_admin = %d \n";
    $args[] = 1;
  }


  $result = db_query($query, $args);
  $nids = array();
  while ($row = db_fetch_object($result)) {
    $nids[] = $row->nid;
  }

  return $nids;
}


/**
 *
 * Get the administrator of a group by type
 *
 * @param string $type
 *  the node type of the group
 * @param integer $uid - the user id of a member of the group
 * @param boolean $manager
 *  1/TRUE -
 *  0/FALSE -
 * @return integer
 *  the uid of the group admin or manager
 *
 */
//function _get_og_admin($type, $uid, $manager = 0) {
	function _get_og_admin_by_type($type, $uid, $manager = 1) {
  $query = '';
  $query .= "SELECT ou2.uid
            FROM {og_uid} ou1, {og_uid} ou2, {node} n1
            WHERE n1.type = '%s'
            AND n1.nid = ou1.nid
            AND ou1.uid = %d
            AND ou1.nid = ou2.nid
            AND ou2.is_admin = %d";
  $query .= ($manager == 1) ? " AND n1.uid = ou2.uid" : " AND n1.uid <> ou2.uid";
  $query .= " LIMIT 1";

  $args = array($type, $uid, 1);

  $result = db_query($query, $args);
  $admin = db_fetch_object($result);

  return $admin->uid;
}


/**
 * Get student or staff's courses for the academic year.
 *
 *  - students - this is a list of courses they have been allowed to register for at the beginning
 *  of an academic year. The {pe_course_list} table is populated immediately after a student's course
 *  wishlist has been confirmed at the start of the academic year.
 *  - teachers - When a teacher is assigned a course to teach, an entry is made in the {pe_course_list}
 *  and a group (type: pe_group_course) is created for them. The system makes the teacher the administrator of the
 * new group.
 *
 * @param object $account
 *  a user account or object
 * @param integer $ayid
 *  the nid of the academic year
 * @return array $courses
 *  all the courses the teacher or student has been registered for the academic year
 */
function _get_course_list($account, $ayid = 0) {
  $courses = array();
  $ayid = ($ayid > 0) ? $ayid : $account->acad_year->nid;
  $result = db_query("SELECT nid FROM {pe_course_list} WHERE uid = %d AND ayid = %d", $account->uid, $ayid);
  while ($row = db_fetch_object($result)) {
    $courses[] = $row->nid;
  }
  return $courses;
}


// TODO: ???
function _get_course_wishlist($account, $ayid = 0) {
  $courses = array();
  $ayid = ($ayid > 0) ? $ayid : $account->acad_year->nid;
  $result = db_query("SELECT * FROM {pe_course_wishlist} WHERE uid = %d AND ayid = %d", $account->uid, $ayid);
  while ($row = db_fetch_object($result)) {
    $courses[$row->nid] = $row->status;
  }
  return $courses;
}


/**
 * Get all students who have refgistered for a course or courses
 *
 * @param array $nids
 *  nids of courses
 * @return array $uids
 * user ids of students
 */
function _get_course_students($nids) {
  $uids = array();
  if (count($nids) > 0) {
    $result = db_query("SELECT uid FROM {pe_course_list} WHERE nid IN(". implode(',', $nids) .")");
    while ($row = db_fetch_object($result)) {
      $uids[] = $row->uid;
    }
  }
  return $uids;
}

/**
 * Get the minimum and maximum credits/points required to be made by each student
 * for the program and level for the  academic year.
 *
 * @param integer $nid
 *  the unique id of the academic program which holds information about the academic year the student entered the program
 * @param integer $tid
 *  the term id for the study level
 * @return array $credits
 *  an associative array -
 *  - $credits['min'] - minimum
 *  - $credits['max'] - maximum
 *
 */
function _get_min_max_credits($nid, $tid) {
  $credits = array();
  $obj = db_fetch_object(db_query("SELECT nid, tid, credits_min, credits_max FROM {pe_program_credits} WHERE nid = %d AND tid = %d", $nid, $tid));
  if (is_object($obj)) {
    $credits['min'] = $obj->credits_min;
    $credits['max'] = $obj->credits_max;
  }
  return $credits;
}


/**
* Wrapper function to get database information on where CCK has stored its data
*
* @param string $field
*  the field we want to get
* @param string $type
*  the node type
* @return array $db_info
*  an associative array of table and column holding the input field data
*
*/
function _get_content_database_info($field, $type) {
  $field_info = $db_info = array();
  $field_info = content_fields($field, $type);
  $db_info = content_database_info($field_info);
  return $db_info;
}


/**
 * Get the value stored for a node against a field in the database
 *
 * @param integer $nid
 *  the unique id of the node
 * @param string $field
 *  the machine name of the field
 * @param string $type
 *  the name of the field toread
 * @return string/array/object
 *  the value found in the table column for the given node
 */
function _get_field_value($nid, $field, $type) {
  $db_info = _get_content_database_info($field, $type);
  $table = $db_info['table'];
  if (is_array($db_info['columns']['nid'])) {
    $column = $db_info['columns']['nid']['column'];
  }
  elseif (is_array($db_info['columns']['value'])) {
    $column = $db_info['columns']['value']['column'];
  }

  $object = db_fetch_object(db_query("SELECT `%s` FROM {%s} WHERE nid = %d", $column, $table, $nid));

  return $object->$column;
}


/**
 * Helper function to create an associative array of country names mapped to iso3166 2-letter codes
 *
 * return array $countries
 *  associative array of Code2 => Name
 */
function _get_iso3166_countries() {
  $result = db_query("SELECT Code2, Name FROM {world_country} ORDER BY Name");
  $countries = array();
  while ($row = db_fetch_object($result)) {
    $countries[drupal_strtolower($row->Code2)] = $row->Name;
  }
  return $countries;
}



/**
* Helper function to map personal title options specified in cck select options for
* personal title field in personal profiles. This makes translations easier.
*
*/
function _get_personal_title_options() {
 return array(
  'mr' => t('Mr'),
  'mrs' => t('Mrs'),
  'miss' => t('Miss'),
  'ms' => t('Ms'),
  'dr' => t('Dr'),
  'prof' => t('Prof'),
  'dmrs' => t('Dr (Mrs)'),
  'dmiss' => t('Dr (Miss)'),
  'dms' => t('Dr (Ms)'),
  'pmrs' => t('Prof (Mrs)'),
  'pmiss' => t('Prof (Miss)'),
  'pms' => t('Prof (Ms)'),
);

}


/**
* Helper function to map marital status options specified in cck select options for
* marital status field in personal profiles. This makes translations easier.
*
*/
function _get_marital_status_options() {
  return array(
   'single' => t('Single'),
    'partner' => t('With partner'),
    'married' => t('Married'),
    'divorced' => t('Divorced'),
    'separated' => t('Separated'),
    'widowed' => t('widowed'),
  );
}

/**
* Helper function to map Yes/No options specified in cck select options.
* This makes translations easier.
*
*/
function _get_yes_no_options() {
  return array(
    'yes' => t('Yes'),
    'no' => t('No')
  );
}

/**
 * Helper function to translate personal titles for storage and retrieval in the database
 *
 * @param string $str
 * array key or value we want to translate
 * @param boolean $val
 * TRUE, 1 = $str is an array key, so get the value
 * FALSE, 0 = $str is an array value, so get the key
 * @param return
 */
function _translate_personal_title($str, $val = TRUE) {
  $titles = _get_personal_title_options();
  if ($val) {
    return $titles[$str];
  }
  else {
    foreach ($titles as $key => $value) {
      if ($value == $str) {
        return $key;
      }
    }
  }
}


/**
 * Helper function to translate a role id to role name
 *
 * @param integer $rid
 * @return string the role name
 */
function _translate_role_names($rid) {
  switch ($rid) {
    case PHPEDU_STUDENT_RID:
      return t('students');
    case PHPEDU_TEACHER_RID:
      return t('teachers');
    case PHPEDU_ALUMNUS_RID:
      return t('alumni');
    case PHPEDU_STAFF_RID:
      return t('staff');
    case PHPEDU_ADMINISTRATOR_RID:
      return t('administrators');
    case PHPEDU_SECRETARY_RID:
      return t('secretaries');
  }
}

/**
 * Helper function to map entry mode taxonomy terms to translatable strings. All term entries
 * under Entry mode vocabulary should have equivalent entries here
 *
 * @return array
 *  an associative array of short and full representations of entry mode options
 */
function _get_entry_mode_options($str = '') {

  $modes = array();

  if(drupal_strlen($str) > 0) {
    $modes[0] = $str;
  }

  $result = db_query("SELECT mode_short, mode_long FROM {pe_entry_mode}");
  while($row = db_fetch_object($result)) {
    $modes[$row->mode_short] = $row->mode_long;
  }

  return  $modes;

}

/**
 * Helper function to get a vocabulary object (on the assumption that no two vocabularies have the same name).
 * Often called when getting terms for a vocabulary.
 *
 * @param string $vocab
 *  the name of the vocabulry
 * return object
 * holds all available data on the vocabulary
 */
function _get_vocab_vid($vocab) {
  return db_fetch_object(db_query("SELECT vid FROM {vocabulary} WHERE name = '%s'", $vocab));
}


/**
 * Get all the terms in a vocabulary
 *
 * @param string $voc
 *  the name of the vocabulary
 * @param string $str
 *  optional string to indicate no term. Often used when generating select options with a default
 * option for all or no terms selected e.g. <all>, <none>
 *
 * @return array $terms
 *  array of terms in the vocabulary: key = tid, value = name
 *
 */
function _get_terms_for_vocabulary($voc, $str = '') {
  $vocab =  _get_vocab_vid($voc);
  $result = db_query("SELECT tid, name FROM {term_data} WHERE vid = %d", $vocab->vid);
  $terms = array();
  if ($str != '') {
    $terms[0] = $str;
  }
  while ($row = db_fetch_object($result)) {
    $term = new stdClass();
    $term->option = array($row->tid => $row->name);
    $terms[] = $term;
  }
  return $terms;
}



/**
 * Translate a 2-letter iso country code into the country name or vice-versa.
 *
 * @param
 * $str string - either a 2-letter country code or country name
 * @param return string
 *
 * @return string
 * if $str is the Country Code, return the Country
 * if $str is the Country Name, return the Code
 *
 */
function _translate_isocode_country($str) {
  $select = ((drupal_strlen($str)) == 2) ? 'Name' : 'Code2';
  $where = ((drupal_strlen($str)) == 2) ? 'Code2' : 'Name';
  $iso_country = db_fetch_object(db_query("SELECT '%s' FROM {world_country} WHERE '%s' = '%s'", $select, $where, $str));

  return $iso_country->$select;
}


/**
 * Helper function to trim long texts e.g. usernames in limited space, so as not to break the page.
 * @param string $text
 * the long text to be shortened
 * @param integer $len
 * number of characters to return if $text is longer than $len characters. ... is appended to the returned string
 *
 */
function _truncate_string($text, $len) {
  $text = trim($text);
  $string = explode(" ", $text);
  if (count($string) <= $len) {
    return $text;
  }
  else {
    for ($i = 0; $i <= $len; $i++ ) {
      $temp .= $string[$i];
      $temp .= " ";
    }
    $str = trim($temp);
    $str .= ' ...';
  }
  return $str;
}



/**
 * Get an array of nodes with nid as key and title as value. Useful when generating select options.
 *
 * @param array $types
 *  array of node types
 * @param boolean $active
 *  the status of the node
 * @param integer $uid
 *  the uid of the node author
 * @param boolean $nids
 *  whether you want only nids or nid => title array returned
 * @return array
 */
function _get_nodes($types, $active = 1, $uid = 0, $nids = 0) {
  $args = array();
  $query = "SELECT n.nid, n.title FROM {node} n \n";
  $query .= " WHERE n.type IN ('". implode("','", $types) ."') \n";
  $args[] =$types;

  if ($active) {
    $query .= " AND n.status = %d \n";
    $args[] = 1;
  }
  if ($uid > 0) {
    $query .= " AND n.uid = %d \n";
    $args[] = $uid;
  }
  $query .= " ORDER BY n.title";

  $result = db_query($query, $args);
  $options = array();
  while ($row = db_fetch_object($result)) {
    if ($nids == TRUE) {
      $options[] = $row->nid;
    }
    else {
      $options[$row->nid] = $row->title;
    }
  }
  return $options;
}




/**
 * Get all nodes of given types(s) posted to a user's group
 *
 * @param array $types
 * @param boolean $active
 * @param object $account
 * @param array $nids
 * @return array $nodes
 */
function _get_nodes_for_group($types, $active = 1, $account = NULL, $nids = TRUE) {
  $nodes = array();
  if (sizeof($account->og_groups_nids)) {
    $rst = db_query("SELECT n.nid, n.title FROM {og_ancestry} g
                      INNER JOIN {node} n ON (n.nid = g.nid)
                      WHERE g.group_nid IN (". implode(', ', $account->og_groups_nids) .")
                      AND n.status = %d
                      AND n.type IN ('". implode("','", $types) ."')", $active);
    while ($row = db_fetch_object($rst)) {
      if ($nids) {
       $nodes[] = $row->nid;
      }
      else {
       $nodes[$row->nid] = $row->title;
      }
    }
  }
  return $nodes;
}


/**
 * Get node author when only a node id is available
 *
 * @param $nid
 */
function _get_node_author($nid) {
  if ($nid > 0) {
    $author = db_fetch_object(db_query("SELECT uid FROM {node} WHERE nid = %d", $nid));
    return $author->uid;
  }
  else {
    return;
  }
}


/**
 * Create array of group nids => title, suitable for generating select options
 *
 * @param array $nids - node ids of groups
 * @param string $str - text to display as first select option
 * @return array nid => title
 */
function _get_og_node_options($nids, $str) {

	$options = array();

	if(drupal_strlen($str)) {
	 $options[0] = $str;
	}

	if(sizeof($nids)) {
		foreach($nids as $nid) {
			 $options[$nid] = _get_title_from_nid($nid);
		}
	}
	return $options;
}

/**
 * TODOL: token integration
 * 
 * Format full names of users depending on their primary role
 * 
 * @param $account
 * @return string $fullname - format string of the user's full name
 */
function _format_fullnames($account) {

    $fullname = theme('username', $account, $link = 0, $access = 1, $path = '', $attributes = NULL);

    if($account->is_student) {
        $studentid = $account->profileedu->field_studentid[0]['value'];
        $fullname .= (drupal_strlen($studentid)) ? ' ' . $studentid : '';
    }



  return $fullname;
}