<?php
// $Id: pe_quiz.admin.inc,v 1.7 2009/05/31 08:41:19 dakala Exp $

/**
 * @file
 *
 */
 
 
function pe_quiz_admin_settings() {
  $quiz_name = check_plain(variable_get('quiz_name', 'quiz'));
  $form = array();
  // option to globally turn off pass / fail form elements
  $form['quiz_default_close'] = array(
    '#type' => 'textfield',
    '#title' => t('Default number of days before a quiz is closed'),
    '#default_value' => variable_get('quiz_default_close', 30),
    '#description' => t('Supply a number of days to calculate the default close date for new quizzes.'),
  );
  $form['quiz_use_passfail'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display pass / fail options in the quiz form'),
    '#default_value' => variable_get('quiz_use_passfail', 1),
    '#description' => t('Check this to display the pass / fail options in the quiz form. You can still choose to ignore pass / fail options on a quiz by quiz basis if this is checked, but if you want to prohibit other quiz module creators from using these options, unchecked this option.'),
  );
  $form['quiz_default_pass_rate'] = array(
    '#type' => 'textfield',
    '#title' => t('Default percentage needed to pass a quiz'),
    '#default_value' => variable_get('quiz_default_pass_rate', 75),
    '#description' => t('Supply a number between 1 and 100 to set as the default percentage correct needed to pass a quiz. Set to 0 if you want to ignore pass / fail summary information by default.'),
  );
  $form['quiz_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Assessment name'),
    '#default_value' => $quiz_name,
    '#description' => t('How do you want to refer to quizzes accross the site (for example: quiz, test, assessment).  This will affect display text but will not affect menu paths.'),
    '#required' => TRUE,
  );

  $form['extras'] = array(
    '#type' => 'fieldset',
    '#title' => t('General exercise settings'),
  );

  $form['extras']['exercise_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Name for all exercises'),
    '#default_value' => t('Practice'),
    '#description'  => t('This is to diiferentiate general exercises from quizzes, tests or assessments.'),
  );

  $form['extras']['exercise_pass'] = array(
    '#type' => 'textarea',
    '#title' => t('Feedback - pass'),
    '#default_value' => variable_get('exercise_pass', ''),
    '#description'  => t('Message to display if the user passes the exercise.'),
    '#cols' => 40,
    '#rows' => 5,
  );

  $form['extras']['exercise_fail'] = array(
    '#type' => 'textarea',
    '#title' => t('Feedback - fail'),
    '#default_value' => variable_get('exercise_fail', ''),
    '#description'  => t('Message to display if the user passes the exercise.'),
    '#cols' => 40,
    '#rows' => 5,
  );
  $form['extras']['exercise_summary'] = array(
    '#type' => 'textarea',
    '#title' => t('Default message'),
    '#default_value' => variable_get('exercise_summary', t('You have completed the quiz.')),
    '#description'  => t('Default message to display if not using the "Pass/Fail" option for messages.'),
    '#cols' => 40,
    '#rows' => 5,
  );

  return system_settings_form($form);
}


function pe_quiz_questions() {
  $quiz = node_load(arg(1));
  // Set page title
  drupal_set_title(check_plain($quiz->title));
  $output .= drupal_get_form('pe_quiz_questions_form', $quiz);
  return $output;
}


/**
 * Handles "add question" tab
 *
 * Displays form which allows questions to be filtered by taxonomy vocabulary,
 * and assigned to the given quiz
 *
 * @return
 *  HTML output to create page
 */
function pe_quiz_questions_form($form_state, $quiz) {
  $quiz_name = check_plain(variable_get('quiz_name', 'quiz'));

  if ($_POST) {
    if ($_POST['op'] == 'Filter question list') {
      //BE CAREFUL OF THE $_POST['edit'] ARRAY AS THIS VALUE IS LIABLE TO CHANGE WHEN VOCABS ARE ADDED AND DELETED...IF YOU HAVE MORE THAN ONE VOCAB, MAY GOD HELP YOU!!
      $_SESSION['quiz_filter'] = $_POST['edit'][4];
    }
  }

  if (isset($_SESSION['quiz_filter'])) {
    $terms = $_SESSION['quiz_filter'];
  }
  else {
    $terms = array();
  }

  // show the number of questions that this quiz currently has
  $form['numberofquestions'] = array(
    '#prefix' => '<div class="quiz_questions_number">',
    '#value' => t('This @quiz consists of @x @question.', array('@quiz' => $quiz_name, '@x' => check_plain($quiz->number_of_questions), '@question' => format_plural($quiz->number_of_questions, t('question'), t('questions')))),
    '#suffix' => '</div><br />'."\n"
  );


  // Display filtering options
  if (_quiz_taxonomy_select() != array()) {
    $form['taxonomy_filter'] = array(
      '#type' => 'fieldset',
      '#title' => t('Select one or more terms to filter the question list'),
    );
    $form['taxonomy_filter']['taxonomy']['#tree'] = TRUE;

    $form['taxonomy_filter']['taxonomy'] = _quiz_taxonomy_select($terms);
    $form['taxonomy_filter']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Filter question list'),
    );
  }

  // Grab current question status, if any
  $questions = pe_quiz_filter_question_list($terms);

  $result = db_query('SELECT question_nid, question_status FROM {pe_quiz_questions} WHERE quiz_nid = %d', $quiz->nid);
  while ($assigned_question = db_fetch_object($result)) {
    if (array_key_exists($assigned_question->question_nid, $questions)) {
      $the_question =& $questions[$assigned_question->question_nid];
      $the_question->status = $assigned_question->question_status;
    }
  }

  // Display filtered question list
  $form['filtered_question_list'] = array(
    '#type' => 'fieldset',
    '#title' => t('The following questions were found'),
    '#theme' => 'pe_quiz_filtered_questions',
  );

  $form['filtered_question_list']['question_status']['#tree'] = TRUE;

  foreach ($questions as $key => $question) {
    $form['filtered_question_list']['question_status'][$question->nid] = array(
      '#type' => 'radios',
      '#options' => array(QUESTION_RANDOM => '', QUESTION_ALWAYS => '', QUESTION_NEVER => ''),
      '#default_value' => $question->status,
    );

    $form['filtered_question_list']['question'][$question->nid] = array(
      '#type' => 'markup',
      '#value' => $question->question,
    );
    $form['filtered_question_list']['type'][$question->nid] = array(
      '#type' => 'markup',
      '#value' => $question->type,
    );
  }

  // Get questions assigned to this quiz
  $questions = _quiz_get_questions();

  // Display questions
  $form['assigned_questions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Questions assigned to this @quiz', array('@quiz' => $quiz_name)),
  );
  $form['assigned_questions']['questions'] = array(
    '#type' => 'markup',
    '#value' => theme('pe_quiz_question_table', $questions),
  );

  // Display links to create other questions
  $form['additional_questions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Create additional questions'),
    '#theme' => 'pe_additional_questions',
  );

  $addmore = '&nbsp;<em>/</em>&nbsp;';
  foreach (_quiz_get_question_types() as $type) {
    $addmore .= l(drupal_ucfirst(eregi_replace('pe_', '', $type)), "node/add/$type", array('title' => t("Go to $type administration"))) .'&nbsp;<em>/</em>&nbsp;';
  }

  $form['additional_questions'][$type] = array(
    '#type' => 'markup',
    '#value' => $addmore,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit questions'),
  );

  return $form;
}

/**
*
* ($form_id, $values)
*
 * Submit function for quiz_questions
 *
 * Updates from the "add questions" tab
 *
 * @param $form_id
 *   A string containing the form id
 * @param $values
 *   Array containing the form values
*/
function pe_quiz_questions_form_submit($form, &$form_state) {
  $quiz_name = check_plain(variable_get('quiz_name', 'Quiz'));
  // load the node
  $quiz = node_load(arg(1));

  // Update quiz with selected question options
  if (!pe_quiz_update_questions($form_state['values']['question_status'])) {
    form_set_error('', t('Either no questions were selected, or there was a problem updating your @quiz. Please try again.', array('@quiz' => $quiz_name)));
    return;
  }
  // Determine how many more questions are required
  $qnum = $quiz->number_of_questions;
  $anum_random = pe_quiz_get_num_questions($quiz->nid, QUESTION_RANDOM);
  $anum_always = pe_quiz_get_num_questions($quiz->nid, QUESTION_ALWAYS);
  $anum_total = $anum_always + $anum_random;

  // If we have some random questions, increase this number by one.
  if ($anum_random > 0) {
    $anum_always++;
  }

  // If there are not enough questions, lower the number of questions and let the user know.
  if ($anum_total < $qnum) {
    drupal_set_message(t('The number of questions for this quiz have been lowered to %anum to match the number of questions you assigned.', array('%anum' => theme('placeholder', $anum_total))), 'status');
    db_query("UPDATE {pe_quiz} SET number_of_questions = %d WHERE nid = %d", $anum_total, $quiz->nid);
  }
  else if ($anum_always > $qnum) {
    // If there are too many questions set to "always", increase the number of questions and let the user know.
    drupal_set_message(t('The number of questions for this quiz have been increased to %anum to match the number of questions you assigned.', array('%anum' => theme('placeholder', $anum_always))), 'status');
    db_query("UPDATE {pe_quiz} SET number_of_questions = %d WHERE nid = %d", $anum_always, $quiz->nid);
  }
  else {
    // Otherwise just give general feedback.
    drupal_set_message(t('Questions updated successfully.'));
  }
}


/*
 * Delete Result
 */
function pe_quiz_admin_result_delete() {
  if (user_access('administer quizzes')) {
    $rid = arg(2);
    return drupal_get_form('pe_quiz_admin_result_delete_confirm', $rid);
  }
  else {
    drupal_access_denied();
  }
}

function pe_quiz_admin_result_delete_confirm(&$form_state, $rid) {
  $quiz_name = check_plain(variable_get('quiz_name', 'Quiz'));
  $form['rid'] = array('#type' => 'hidden', '#value' => $rid);
  return confirm_form($form,
        t('Are you sure you want to delete this @quiz result?', array('@quiz' => $quiz_name)),
        'admin/phpedu/results',
        t('This action cannot be undone.'),
        t('Delete'),
        t('Cancel') );
}


function pe_quiz_admin_result_delete_confirm_submit($form, &$form_state) {
  db_query("DELETE FROM {pe_quiz_result} WHERE rid = %d", $form_state['values']['rid']);
  db_query("DELETE FROM {pe_quiz_question_results} WHERE result_rid = %d", $form_state['values']['rid']);
  drupal_set_message(t('Deleted result.'));
  $form_state['redirect'] = 'admin/phpedu/results';
  return;
}


/**
 * Quiz Admin
 *
 */
function pe_quiz_admin_results_summary() {
  $results = _quiz_get_results();
  return theme('pe_quiz_admin', $results);
}


/*
 * Quiz Results Admin
 */
function pe_quiz_admin_results() {
  $result = db_fetch_object(db_query('SELECT pqr.quiz_nid FROM {pe_quiz_result} pqr LEFT JOIN {pe_quiz} pq ON  (pqr.quiz_nid = pq.nid) WHERE pqr.rid = %d', arg(2)));
  if ($result) {
    if ($result->nid > 0) {
      $quiz = node_load($result->nid);
    }
    else {
      $quiz = _get_practice_properties();
    }
    $questions = _quiz_get_answers(arg(2));
    $score = pe_quiz_calculate_score(arg(2));
    $summary = _quiz_get_summary_text($quiz, $score);

    return theme('pe_quiz_admin_summary', $quiz, $questions, $score, $summary);
  }
  else {
    drupal_not_found();
  }
}

