<?php
// $Id: pe_quiz.pages.inc,v 1.9 2010/02/24 06:06:54 dakala Exp $

/**
 * @file
 *
 */

/**
 * Theme a question page
 *
 * @param $quiz
 *   The quiz node object
 * @param $question_node
 *   The question node
 * @return
 *   Themed html
 */
function theme_pe_quiz_take_question($quiz_result, $question_node) {
  //Calculation for quiz progress bar
  if ($quiz_result->quiz_nid > 0) {
    $quiz_title = _get_title_from_nid($quiz_result->quiz_nid);
  }
  else {
    $question_number = $quiz_result->number_of_questions - count($_SESSION['quiz']['quiz_questions']);
    $quiz_title = t('Practice exercise');
  }

  // Set the title here in case themers want to do something different
  drupal_set_title($quiz_title);

  // Return the elements of the page
  $output = '';
  $number_of_questions = $quiz_result->number_of_questions;
  $output .= theme('pe_quiz_progress', $question_number, $number_of_questions);
  $output .= module_invoke($question_node->type, 'render_question', $question_node);

  return $output;
}


/**
 * Theme a progress indicator for use during a quiz
 *
 * @param $question_number
 *   The position of the current question in the sessions' array
 * @param $num_of_question
 *   The number of questions for this quiz as returned by quiz_get_number_of_questions()
 * @return
 *   Themed html
 */
function theme_pe_quiz_progress($question_number, $num_of_question) {

  // Determine the percentage finished (not used but left for other implementations)
  //$progress = ($question_number*100)/$num_of_question;

  // Get the current question # by adding one
  $current_question = $question_number + 1;

  // return html
  $output = '';
  $output .= '<div id="quiz_progress">';
  $output .= t('Question @x of %y', array('@x' => $current_question, '%y' => $num_of_question));
  $output .= '</div><br />'."\n";
  return $output;

}


/**
 * Theme the summary page after the quiz has been completed
 *
 * @param $quiz
 *   The quiz node object
 * @param $questions
 *   The questions array as defined by _quiz_get_answers
 * @param $score
 *   Array of score information as returned by quiz_calculate_score()
 * @param $summary
 *   Filtered text of the summary
 * @return
 *   Themed html
 */
function theme_pe_quiz_take_summary($quiz, $questions, $score, $summary) {

  // Set the title here so themers can adjust
  $quiz_title = ($quiz->title != '') ? check_plain($quiz->title) : t('Practice exercise');
  drupal_set_title($quiz_title);

  // Display overall result
  $output = '';
  $output .= '<div id="quiz_score_possible">'. t('You got @num_correct of @question_count correct.', array('@num_correct' => $score['num_correct'], '@question_count' => $score['question_count'])) .'</div>'."\n";
  $output .= '<div id="quiz_score_percent">'. t('Your score: @score%', array('@score' => $score['percentage_score'])) .'</div>'."\n";
  $output .= '<div id="quiz_summary">'. $summary .'</div>'."\n";

  // Get the feedback for all questions
  $output .= theme('pe_quiz_feedback', $questions, TRUE, TRUE);

  return $output;

}


function theme_pe_quiz_feedback($questions, $show_points = TRUE, $show_feedback = FALSE) {
  foreach ($questions as $key => $questions_set) {
      $question_type = $questions_set['type'];
  }
  reset($questions);

  switch ($question_type) {

      case 'pe_matching':
        $rows = array();
        $header = array(
          t('Question'),
          t('User Answer'),
          t('Correct Answer'),
          '&nbsp;',
          );

        while (list($key, $question) = each($questions)) {
          $cols = array();
          // Get the answer table for this question
          $question['qanswer'] = unserialize($question['qanswer']);
          $result = module_invoke($question['type'], 'calculate_results', $question['qanswer']['answers'], $question['qanswer']['tried'], $show_points, $show_feedback);
          $rows = $result['resultstable'];
          $q_output = '<div class="quiz_summary_question"><span class="quiz_question_bullet">Q:</span> '. $question['question'] .'</div>';
        }

        $output = '';
        $output .= t('<p><strong>Question Result(s)</strong></p>');
        $output .= theme('table', $header, $rows);
      break;

      case 'pe_multichoice':
        $rows = array();
        $header = array(t('Question Result(s)'), '');

        while (list($key, $question) = each($questions)) {
          $cols = array();
          // Get the answer table for this question
          $question['qanswer'] = unserialize($question['qanswer']);
          $result = module_invoke($question['type'], 'calculate_results', $question['qanswer']['answers'], $question['qanswer']['tried'], $show_points, $show_feedback);
          // Build the question answers header (add blank space for IE)
          $innerheader = array(t('Answers'));
          if ($show_points) {
            $innerheader[] = array(
                        'data' => t('Correct'),
                        'width' => '10%',
                        'nowrap' => 'nowrap',
                        );
          }
          $innerheader[] = array(
                        'data' => t('User'),
                        'width' => '10%',
                        'nowrap' => 'nowrap',
                        );

          if ($show_feedback) {
              $innerheader[] = array(
                          'data'  => '&nbsp;',
                          'width' => '5%',
                          'nowrap' => 'nowrap',
                          );
            }

          // Add the cell with the question and the answers
          $q_output = '<div class="quiz_summary_question"><span class="quiz_question_bullet">Q:</span> '. $question['question'] .'</div>';
          $q_output .= theme('table', $innerheader, $result['resultstable'], array('width' => '100%')) .'<br />';
          $cols[] = array('data' => $q_output, 'class' => 'quiz_summary_qcell');

          // Get the score result for each question.
          if ($result['score'] == 1) {
            $cols[] = array('data' => _pe_quiz_score_correct(), 'class' => 'quiz_summary_qcell');
          }
          else {
            $cols[] = array('data' => _pe_quiz_score_incorrect(), 'class' => 'quiz_summary_qcell');
          }

          // pack all of this into this row
          $rows[] = array('data' => $cols);
        }
        $output = theme('table', $header, $rows);
      break;

      case 'pe_gapfilling':
        $header = array('#', 'Question', '');
        $rows = array();

        $i = 1;
        foreach ($questions as $key => $question) {
         $question['qanswer'] = unserialize($question['qanswer']);
         $result = module_invoke($question['type'], 'calculate_results', $question['qanswer']['answers'], $question['qanswer']['tried'], $show_points, $show_feedback);

         $rows[] = array(
           array('data' => $i++),
           array('data' => eregi_replace('<!-->', '<strong>'. $result['resultstable'][0][1] .'</strong>', $question['question']) .' '. $result['correction']),
           array('data' => $result['resultstable'][0][2]),
           );
        }
        $output = '';
        $output .= t('<p><strong>Question Result(s)</strong></p>');
        $output .= theme('table', $header, $rows);

       break;
  }
  return $output;
}


/**
 * Theme the summary page for user results
 *
 * @param $quiz
 *   The quiz node object
 * @param $questions
 *   The questions array as defined by _quiz_get_answers
 * @param $score
 *   Array of score information as returned by quiz_calculate_score()
 * @param $summary
 *   Filtered text of the summary
 * @return
 *   Themed html
 */
function theme_pe_quiz_user_summary($quiz, $questions, $score, $summary) {

  // Set the title here so themers can adjust
  drupal_set_title(check_plain($quiz->title));

  // Display overall result
  $output = '';
  $output .= '<div id="quiz_score_possible">'. t('You got @num_correct of @question_count correct.', array('@num_correct' => $score['num_correct'], '@question_count' => $score['question_count'])) .'</div>'."\n";
  $output .= '<div id="quiz_score_percent">'. t('Your score was: @score%', array('@score' => $score['percentage_score'])) .'</div>'."\n";
  $output .= '<div id="quiz_summary">'. $summary .'</div>'."\n";

  // Get the feedback for all questions - all questions and answers displayed
  $output .= theme('pe_quiz_feedback', $questions, TRUE, TRUE);
  return $output;
}


/**
 * Theme the user results page
 *
 * @param $results
 *   An array of quiz information
 * @return
 *   Themed html
 */
function theme_pe_quiz_get_user_results($results) {
  if ($results['nid'] > 0) {
    $quiz_title = check_plain($result['title']);
  }
  else {
    $quiz = _get_practice_properties();
    $quiz_title = $quiz->title;
  }

  $output = '';
  $i = 1;
  $rows = array();
  while (list($key, $result) = each($results)) {
    $rows[] = array(
      $i,
      $quiz_title,
      _translate_question_type($result['type']),
      check_plain($result['name']),
      $result['rid'],
      format_date($result['time_start'], 'small'),
      ($result['time_end'] > 0) ? format_date($result['time_end'], 'small') : t('In Progress'),
      l("Details", "user/quiz/". $result['rid'] ."/userresults"),
    );
    $i++;
  }

  $header = array(
    t("#"),
    t('Quiz Title'),
    t('Quiz Type'),
    t('Username'),
    t('Result ID'),
    t('Time Started'),
    t('Time Finished'),
    t('Operation')
    );

  if (isset($rows)) {
    $output .= theme('table', $header, $rows);
  }
  else {
    // TODO: Should this actually say "No quizzes found"?
    $output .= t('No questions found.');
  }
  return $output;
}


/**
 * Theme the results table
 *
 * @param $results
 *   As returned by _quiz_get_results()
 */
function theme_pe_quiz_admin($results) {
  if ($results['nid'] > 0) {
    $quiz_title = check_plain($result['title']);
  }
  else {
    $quiz = _get_practice_properties();
    $quiz_title = $quiz->title;
  }

  $output = '';
  $rows = array();

  while (list($key, $result) = each($results)) {
    $rows[] = array(
      l("view", "admin/quiz/". $result['rid'] ."/view") ." | ". l("delete", "admin/quiz/". $result['rid'] ."/delete"),
      $quiz_title,
      _translate_question_type($result['type']),
      check_plain($result['name']),
      $result['rid'],
      format_date($result['time_start'], 'small'),
      ($result['time_end'] > 0) ? format_date($result['time_end'], 'small') : t('In Progress'),
    );
  }

  $header = array(
    t('Action'),
    t('Quiz Title'),
     t('Quiz Type'),
    t('Username'),
    t('Result ID'),
    t('Time Started'),
    t('Time Finished'),
    );

  if (isset($rows)) {
    $output .= theme('table', $header, $rows);
   }
   else {
    $output .= t('No quizzes or exercises found.');
  }
  return $output;
}


/**
 * Theme the summary page for admins
 *
 * @param $quiz
 *   The quiz node object
 * @param $questions
 *   The questions array as defined by _quiz_get_answers
 * @param $score
 *   Array of score information as returned by quiz_calculate_score()
 * @param $summary
 *   Filtered text of the summary
 * @return
 *   Themed html
 */
function theme_pe_quiz_admin_summary($quiz, $questions, $score, $summary) {
  // Set the title here so themers can adjust
  drupal_set_title(check_plain($quiz->title));

  // Display overall result
  $output = '';
  $output .= '<div id="quiz_score_possible">'. t('This person got @num_correct of @question_count correct.', array('@num_correct' => $score['num_correct'], '@question_count' => $score['question_count'])) .'</div>'."\n";
  $output .= '<div id="quiz_score_percent">'. t('Total score: @score%', array('@score' => $score['percentage_score'])) .'</div>'."\n";
  $output .= '<div id="quiz_summary">'. $summary .'</div>'."\n";

  // Get the feedback for all questions
  $output .= theme('pe_quiz_feedback', $questions, TRUE, TRUE);

  return $output;
}


/**
 * Theme a table containing array of questions and options
 *
 * @param $questions
 *   Array of question nodes
 * @return
 *   HTML to output table
 */
function theme_pe_quiz_question_table($questions) {
  $output = '';
  $status_descriptions = array(t('Random'), t('Always'), t('Never'));
  while (list($key, $question) = each($questions)) {
    $rows[] = array(
      $status_descriptions[$question->status],
      check_markup($question->question),
      $question->type);
  }
  $header = array(t('Status'), t('Question'), t('Type'));

  if (isset($rows)) {
    $output .= theme('table', $header, $rows);
  }
  else {
    $output .= 'No questions found.';
  }
  return $output;
}


/**
 * Theme the filtered question list
 */
function theme_pe_quiz_filtered_questions($form) {
  $header = array(t('Random'), t('Always'), t('Never'), t('Question'), t('Type'));
  $rows = array();

  while (list($nid, $values) = each($form['question_status'])) {
    if (is_numeric($nid)) {
      $rows[] = array(
        drupal_render($form['question_status'][$nid][0]),
        drupal_render($form['question_status'][$nid][1]),
        drupal_render($form['question_status'][$nid][2]),
        drupal_render($form['question'][$nid]),
        drupal_render($form['type'][$nid])
      );
    }
  }
  if (isset($rows)) {
    $output .= theme('table', $header, $rows);
  }
  else {
    $output .= t('No questions found.');
  }
  return $output;
}


/**
 * Theme the node view for quizzes
 */
function theme_pe_quiz_view(&$node, $teaser = FALSE, $page = FALSE) {
  $output = '';
  $quiz_name = check_plain(variable_get('quiz_name', 'quiz'));

  // Ouput quiz options
  $output .= '<h3>'. t('@quiz Options', array('@quiz' => drupal_ucfirst($quiz_name))) .'</h3>';

  $header = array(
    t('# of Questions'),
    t('Shuffle?'),
    t('Allow Backwards?'),
    t('Feedback'),
    t('Number of takes')
  );
  $shuffle = $node->shuffle == 1 ? t('Yes') : t('No');
  $backwards = $node->backwards_navigation == 1 ? t('Yes') : t('No');
  $feedback_options = array(
    t('At the end of each @quiz', array('@quiz' => $quiz_name)),
    t('After each question'),
    t('Do not show')
  );
  $feedback = $feedback_options[$node->feedback_time];
  $takes = $node->takes == 0 ? t('Unlimited') : check_plain($node->takes);
  $rows = array();
  $rows[] = array(
    check_plain($node->number_of_questions),
    $shuffle,
    $backwards,
    $feedback,
    $takes
  );
  $output .= theme('table', $header, $rows);

  // Format Quiz Dates
  $output .= '<h3>'. t('@quiz start/end', array('@quiz' => $quiz_name)) .'</h3>';
  if (!$node->quiz_always) {
    $output .= "<p>". format_date($node->quiz_open) ." &mdash; ". format_date($node->quiz_close) ."</p>";
    $output .= "<p><strong>". t('Days @quiz live for', array('@quiz' => $quiz_name)) ."</strong> ". floor((strtotime($node->close) - strtotime($node->open)) / 60 / 60 / 24) ."</p>";

    $remaining = floor(($node->quiz_close - time()) / 60 / 60 / 24);
    $remaining = ($remaining < 0)?"Expired":$remaining;
    $output .= "<p><strong>Days remaining:</strong> ". $remaining ."</p>";

    $elapsed = floor((time() - $node->quiz_open) / 60 / 60 / 24);
    $elapsed = ($elapsed < 0)?(-$elapsed) ." days to go":$elapsed;
    $output .= "<p><strong>Days since start:</strong> ". $elapsed ."</p>";
  }
  else {
    $output .= '<p>'. t('This Quiz is always available.') .'</p>'."\n";
  }

  // Format taxonomy selection (if applicable)
  if (function_exists(taxonomy_node_get_terms)) {
    $output .= '<h3>'. t('Taxonomy selection') .'</h3>';
    $terms = array();
    foreach (taxonomy_node_get_terms($node->nid) as $term) {
      $terms[] = check_plain($term->name);
    }
    if (!empty($terms)) {
      $terms = implode(', ', $terms);
      $output .= "<p>$terms</p>";
    }
    else {
      $output .= '<p>'. t('No selected terms found') .'</p>';
    }
  }

  // Format pass / fail and summary options
  if ($node->pass_rate || $node->summary_default || $node->summary_pass) {
    if ($node->pass_rate) {
      $output .= '<h3>'. t('Pass / fail and summary options') .'</h3>'."\n";
      $output .= '<p><strong>'. t('Percentage needed to pass:') .'</strong> '. check_plain($node->pass_rate) .'</p>'."\n";
      $output .= '<div><strong>'. t('Summary text if the student passed:') .'</strong>';
      $output .= ($node->summary_pass) ? check_markup($node->summary_pass) : t('No text defined.');
      $output .= '</div>'."\n";
    }
    $output .= '<div><strong>'. t('Default summary text:') .'</strong>';
    $output .= ($node->summary_default) ? check_markup($node->summary_default) : t('No text defined.');
    $output .= '</div>'."\n";
  }

  // Format quiz questions
  $output .= '<h3>'. t('@quiz Questions', array('@quiz' => $quiz_name)) .'</h3>';
  $questions = _quiz_get_questions();
  $output .= theme('pe_quiz_question_table', $questions);

  return $output;
}
