<?php
// $Id: phpedu_profile.profile,v 1.9 2010/02/26 22:35:32 dakala Exp $

/**
 * Default domain name of the site.
 */
define('PHPEDU_DEFAULT_DOMAIN', 'localhost.localdomain');

/**
 * Default email acount for the site.
 */
define('PHPEDU_DEFAULT_SITE_MAIL', 'website');

/**
 * Default username for the admin user on the site (uid 1), which can be changed
 *  during the installation process.
 */
define('PHPEDU_DEFAULT_ADMIN_USER', 'admin');

/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *   An array of modules to enable.
 */
function phpedu_profile_profile_modules() {
  $modules = array(
        // core required
        'color', 'comment', 'help', 'menu', 'dblog','block', 'filter', 'node', 'system', 'user',
        // core optional
        'taxonomy', 'blog', 'book', 'contact',  'path', 'poll', 'update', 'statistics', 'syslog', 'php', 'tracker', 'trigger',
        // cck
        'content', 'content_copy', 'text', 'number', 'optionwidgets', 'email', 'link', 'install_profile_api', 'cck_sync', 'taxonomy_export',
        'computed_field', 'nodereference', 'userreference', 'content_permissions', 'fieldgroup',
        // views
        'views', 'views_ui', 'views_export',
        // contrib
        'date_api', 'date_timezone', 'date', 'date_popup', 'date_repeat', 'date_tools',  'calendar', 'calendar_ical', 'jcalendar',
        'advanced_help', 'content_profile', 'clone', 'token', 'token_actions',
        // phpedu
        'pe_edu', 'pe_program', 'pe_course', 'pe_lesson', 'pe_admission','pe_assignment', 'pe_quiz','pe_gapfilling', 'pe_multichoice','pe_matching',
  );

  if (version_compare(PHP_VERSION, '5.2', '<')) {
    $modules[] = 'date_php4';
  }

  return $modules;
}


/**
* Implementation of hook_schema().
*/
function og_hack_schema() {
  $schema['og'] = array(
        'fields' => array(
          'nid' => array('type' => 'int', 'unsigned' => TRUE, 'not null' => TRUE),
          'og_selective' => array('type' => 'varchar', 'length' => 255, 'not null' => FALSE, 'default' => NULL),
          'og_description' => array('type' => 'varchar', 'length' => 255, 'not null' => FALSE, 'default' => NULL),
          'og_register' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'og_directory' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'og_notification' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'og_language' => array('type' => 'varchar', 'length' => 12, 'not null' => FALSE, 'default' => ''),
          'og_private' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0)
        ),
        'primary key' => array('nid'),
  );

  $schema['og_ancestry'] = array(
        'fields' => array(
          'nid' => array('type' => 'int', 'unsigned' => TRUE, 'not null' => TRUE),
          'group_nid' => array('type' => 'int', 'unsigned' => TRUE, 'not null' => TRUE),
          'is_public' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 1),
        ),
        'unique keys' => array(
          'nid'     => array('nid'),
          'group_nid'     => array('group_nid')
          ),
  );

  $schema['og_uid'] = array(
        'fields' => array(
          'nid' => array('type' => 'int', 'unsigned' => TRUE, 'not null' => TRUE),
          'og_role' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'is_active' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'is_admin' => array('type' => 'int', 'size' => 'tiny', 'not null' => TRUE, 'default' => 0),
          'uid' => array('type' => 'int', 'not null' => TRUE),
          'mail_type' => array('type' => 'int', 'not null' => FALSE, 'default' => 0),
          'created' => array('type' => 'int', 'not null' => FALSE, 'default' => 0),
          'changed'         => array('description' => t('Time when this membership was last changed.'),'type' => 'int','size' => 'normal', 'not null' => FALSE, 'default' => 0,
              ),
        ),
        'primary key' => array('nid,uid'),
  );

  $schema['og_access_post'] = array(
    'description'     => 'Global properties for group posts.',
    'fields'          => array(
      'nid'             => array(
        'description'     => t("The post's {node}.nid."),
        'type'            => 'int',
        'size'            => 'normal',
        'not null'        => TRUE,
      ),
      'og_public'       => array(
        'description'     => t('Is this a public or private post?'),
        'type'            => 'int',
        'size'            => 'tiny',
        'default'         => 1,
        'not null'        => TRUE,
      ),
    ),
    'primary key'       => array('nid'),
  );

  return $schema;
}

/**
 * og.module install hack.
 * For some reason og install fails so we need this workaround FTTB
 *
 * http://drupal.org/node/413862#comment-1402020 (slake)
 */
function phpedu_profile_install_og() {
  // Create tables.
  drupal_install_schema('og_hack');

  db_query("UPDATE {system} SET status = 1 WHERE name = 'og_access'");
  db_query("UPDATE {system} SET status = 1 WHERE name = 'og_actions'");
  db_query("UPDATE {system} SET status = 1 WHERE name = 'og_views'");
  db_query("UPDATE {system} SET status = 1 WHERE name = 'og'");
  db_query("UPDATE {system} SET weight = 1 WHERE name = 'og_access'");

  // default group nodes
  $group_nodes = array('group', 'pe_group_advisers', 'pe_group_course', 'pe_group_registration');
  foreach($group_nodes as $type) {
    variable_set('og_content_type_usage_'. $type, 'group');
  }

}



/**
 * Return a description of the profile for the initial installation screen.
 *
 * @return
 *   An array with keys 'name' and 'description' describing this profile,
 *   and optional 'language' to override the language selection for
 *   language-specific profiles.
 */
function phpedu_profile_profile_details() {
  return array(
    'name' => 'phpEdu LMS site',
    'description' => 'Select this profile to create a phpEdu site.'
  );
}

/**
 * Return a list of tasks that this profile supports.
 *
 * @return
 *   A keyed array of tasks the profile will perform during
 *   the final stage. The keys of the array will be used internally,
 *   while the values will be displayed to the user in the installer
 *   task list.
 */
function phpedu_profile_profile_task_list() {

}

/**
 * Perform any final installation tasks for this profile.
 *
 * @param $task
 *   The current $task of the install system. When hook_profile_tasks()
 *   is first called, this is 'profile'.
 * @param $url
 *   Complete URL to be used for a link or form action on a custom page,
 *   if providing any, to allow the user to proceed with the installation.
 *
 * @return
 *   An optional HTML string to display to the user. Only used if you
 *   modify the $task, otherwise discarded.
 */
function phpedu_profile_profile_tasks(&$task, $url) {
    // install_profile_api
    install_include(phpedu_profile_profile_modules());
    
    // og custom install
    phpedu_profile_install_og();

    phpedu_profile_create_content_types();

    phpedu_profile_import_taxonomy();

    phpedu_profile_create_roles();

    phpedu_profile_configure_site();

    // Update the menu router information.
    menu_rebuild();
}

/**
 * Create/update all the content type definitions for phpEdu.
 * This function looks for the latest CCK update versions under
 * sites/all/modules/phpedu/pe_edu/cck directory. Subdirectories
 * located there will be named after the corresponding schema
 * version.
 *
 * CCK definitions inthe most recent subdirectory will be used
 * by this function to create and update content types and fields
 *
 */
function phpedu_profile_create_content_types() {
    // install latest version of CCK types and fields
    $path = drupal_get_path('module', 'pe_edu') .'/cck';
    $path .=  '/6005';

  if ($handle = opendir($path)) {
    while ($file = readdir($handle)) {
      if (preg_match('@(.*)\.inc$@', $file)) {
        $file_path = $path .'/'. $file;
                cck_sync_from_file($file_path);
      }
    }
  }

  // default group nodes
  $profile_nodes = array(
    'profile',
    'profileedu',
    'profileeducation',
    'profilekin',
    'profilejob'
    );
  foreach($profile_nodes as $type) {
    variable_set('content_profile_use_'. $type, TRUE);
  }

  // default date/time zone
  $date_default_timezone_name = variable_get('date_default_timezone_name', '');
  if($date_default_timezone_name == '') {
    variable_set('date_default_timezone_name', date_default_timezone_name());
  }

}

/**
 * Create roles and configure permissions for each one.
 *
 */
function phpedu_profile_create_roles() {

  // TODO: permissions for new pe_admission fields

  // Perms for the fixed permissions
  $anon_permissions = array(
  'access printer-friendly version',
  'access comments',
  'view field_acad_program_id',
  'view field_acad_term_id',
  'view field_acad_year',
  'view field_acad_year_id',
  'view field_academic',
  'view field_acronym',
  'view field_activities',
  'view field_address',
  'view field_ahead',
  'view field_ahead_title',
  'view field_allow_uploads',
  'view field_antireq',
  'view field_assignment_question_id',
  'view field_author',
  'view field_awards',
  'view field_business_name',
  'view field_campus_id',
  'view field_career',
  'view field_certificate',
  'view field_city',
  'view field_code',
  'view field_conclusion',
  'view field_contact_person',
  'view field_coreq',
  'view field_country',
  'view field_course_id',
  'view field_credits',
  'view field_dateofdeath',
  'view field_duration',
  'view field_edition',
  'view field_email',
  'view field_end_date',
  'view field_entry_mode',
  'view field_evaluation',
  'view field_eventrepeat_date',
  'view field_fax',
  'view field_firstname',
  'view field_floor',
  'view field_gender',
  'view field_hall_name',
  'view field_hall_number',
  'view field_head',
  'view field_head_title',
  'view field_history',
  'view field_hours',
  'view field_imprint',
  'view field_institution',
  'view field_interests',
  'view field_introduction',
  'view field_ip',
  'view field_isbn_electronic',
  'view field_isbn_hardback',
  'view field_isbn_paperback',
  'view field_issn_electronic',
  'view field_issn_paperback',
  'view field_issue',
  'view field_languages',
  'view field_lastname',
  'view field_late_end_date',
  'view field_lesson_id',
  'view field_main',
  'view field_main_section',
  'view field_marital_status',
  'view field_max_score',
  'view field_methodology',
  'view field_mobile',
  'view field_nonreq',
  'view field_objectives',
  'view field_parent_section',
  'view field_percent',
  'view field_personal_title',
  'view field_phone',
  'view field_position',
  'view field_postbox',
  'view field_postcode',
  'view field_prereq',
  'view field_publication_date',
  'view field_reason',
  'view field_remarks',
  'view field_requirements',
  'view field_resources',
  'view field_room',
  'view field_room_number',
  'view field_salary',
  'view field_seats',
  'view field_section',
  'view field_section_id',
  'view field_start_date',
  'view field_studentid',
  'view field_supplement',
  'view field_term',
  'view field_url',
  'view field_volume',
  'access content',
  'inspect all votes',
  'access all views',
  );
  install_add_permissions(DRUPAL_ANONYMOUS_RID, $anon_permissions);

  $auth_permissions = array(
    'view advanced help index',
    'view advanced help popup',
    'view advanced help topic',
    'create blog entries',
    'delete own blog entries',
    'edit own blog entries',
    'access printer-friendly version',
    'access comments',
    'post comments',
    'access site-wide contact form',
    'view field_accepted',
    'view field_validated',
    'view field_acad_program_id',
    'view field_acad_term_id',
    'view field_acad_year',
    'view field_acad_year_id',
    'view field_academic',
    'view field_acronym',
    'view field_activities',
    'view field_address',
    'view field_ahead',
    'view field_ahead_title',
    'view field_allow_uploads',
    'view field_antireq',
    'view field_assignment_question_id',
    'view field_author',
    'view field_awards',
    'view field_business_name',
    'view field_campus_id',
    'view field_career',
    'view field_certificate',
    'view field_city',
    'view field_code',
    'view field_conclusion',
    'view field_contact_person',
    'view field_coreq',
    'view field_country',
    'view field_course_id',
    'view field_credits',
    'view field_dateofdeath',
    'view field_duration',
    'view field_edition',
    'view field_email',
    'view field_end_date',
    'view field_entry_mode',
    'view field_evaluation',
    'view field_eventrepeat_date',
    'view field_fax',
    'view field_firstname',
    'view field_floor',
    'view field_gender',
    'view field_hall_name',
    'view field_hall_number',
    'view field_head',
    'view field_head_title',
    'view field_history',
    'view field_hours',
    'view field_imprint',
    'view field_institution',
    'view field_interests',
    'view field_introduction',
    'view field_ip',
    'view field_isbn_electronic',
    'view field_isbn_hardback',
    'view field_isbn_paperback',
    'view field_issn_electronic',
    'view field_issn_paperback',
    'view field_issue',
    'view field_languages',
    'view field_lastname',
    'view field_late_end_date',
    'view field_lesson_id',
    'view field_main',
    'view field_main_section',
    'view field_marital_status',
    'view field_max_score',
    'view field_methodology',
    'view field_mobile',
    'view field_nonreq',
    'view field_objectives',
    'view field_parent_section',
    'view field_percent',
    'view field_personal_title',
    'view field_phone',
    'view field_position',
    'view field_postbox',
    'view field_postcode',
    'view field_prereq',
    'view field_publication_date',
    'view field_reason',
    'view field_remarks',
    'view field_requirements',
    'view field_resources',
    'view field_room',
    'view field_room_number',
    'view field_salary',
    'view field_seats',
    'view field_section',
    'view field_section_id',
    'view field_start_date',
    'view field_studentid',
    'view field_supplement',
    'view field_term',
    'view field_url',
    'view field_volume',
    'access content',
    'create business content',
    'create institution content',
    'create pe_admission content',
    'create pe_publication content',
    'create profile content',
    'create profileeducation content',
    'create profilejob content',
    'create profilekin content',
    'delete own book content',
    'delete own business content',
    'delete own institution content',
    'delete own page content',
    'delete own pe_acad_registration content',
    'delete own pe_acad_term content',
    'delete own pe_acad_year content',
    'delete own pe_admission content',
    'delete own pe_assignment_answer content',
    'delete own pe_assignment_question content',
    'delete own pe_course content',
    'delete own pe_edu content',
    'delete own pe_group content',
    'delete own pe_group_advisers content',
    'delete own pe_group_course content',
    'delete own pe_group_registration content',
    'delete own pe_lesson_content content',
    'delete own pe_lesson_event content',
    'delete own pe_program content',
    'delete own pe_publication content',
    'delete own pe_room content',
    'delete own pe_section content',
    'delete own profile content',
    'delete own profileedu content',
    'delete own profileeducation content',
    'delete own profilejob content',
    'delete own profilekin content',
    'delete own story content',
    'edit own book content',
    'edit own business content',
    'edit own institution content',
    'edit own page content',
    'edit own pe_acad_registration content',
    'edit own pe_acad_term content',
    'edit own pe_acad_year content',
    'edit own pe_admission content',
    'edit own pe_assignment_answer content',
    'edit own pe_assignment_question content',
    'edit own pe_course content',
    'edit own pe_edu content',
    'edit own pe_group content',
    'edit own pe_group_advisers content',
    'edit own pe_group_course content',
    'edit own pe_group_registration content',
    'edit own pe_lesson_content content',
    'edit own pe_lesson_event content',
    'edit own pe_program content',
    'edit own pe_publication content',
    'edit own pe_room content',
    'edit own pe_section content',
    'edit own profile content',
    'edit own profileedu content',
    'edit own profileeducation content',
    'edit own profilejob content',
    'edit own profilekin content',
    'edit own profileother content',
    'edit own story content',
    'revert revisions',
    'view revisions',
    'view course lists',
    'access quizzes', 'cancel own vote',
    'delete own poll content',
    'edit own poll content',
    'vote on polls',
    'upload files',
    'access all views'
  );
  $auth_permissions = array_merge($anon_permissions, $auth_permissions);
  install_add_permissions(DRUPAL_AUTHENTICATED_RID, $auth_permissions);

  // Add required roles.
  $roles = array(
    'student' => array(
      'view field_sample_answer',
      'view field_score',
      'create pe_assignment_answer content',
      'create profileedu content',
      'create profileother content',
      'edit course status',
      'view course registration',
      'view course status',
      'user results'
    ),

    'teacher' => array(
      'add content to books',
      'create new books',
      'post comments without approval',
      'edit field_sample_answer',
      'view field_marked',
      'view field_sample_answer',
      'view field_score',
      'edit field_accepted',
      'edit field_validated',
      'create book content',
      'create page content',
      'create pe_assignment_question content',
      'create pe_course content',
      'create pe_group_course content',
      'create pe_lesson_content content',
      'create pe_lesson_event content',
      'create profileedu content',
      'create profileother content',
      'create story content',
      'create url aliases',
      'edit course status',
      'view course registration',
      'view course status',
      'create gapfilling',
      'edit own gapfilling',
      'create multichoice',
      'edit own multichoice',
      'create quizzes',
      'user results',
      'create poll content',
      'access user profiles'
    ),

    'alumnus' => array(
      'create profileother content',
      'user results'
    ),

    'staff' => array(
      'create profileedu content',
      'create profileother content'
    ),

  'administrator' => array(
    'administer blocks',
    'delete any blog entry',
    'edit any blog entry',
    'add content to books',
    'administer book outlines',
    'create new books',
    'administer comments',
    'post comments without approval',
    'administer site-wide contact form',
    'Use PHP input for field settings (dangerous - grant with care)',
    'grant content access',
    'grant own content access',
    'edit field_acad_program_id',
    'edit field_acad_term_id',
    'edit field_acad_year',
    'edit field_acad_year_id',
    'edit field_academic',
    'edit field_acronym',
    'edit field_activities',
    'edit field_address',
    'edit field_ahead',
    'edit field_ahead_title',
    'edit field_allow_uploads',
    'edit field_antireq',
    'edit field_assignment_question_id',
    'edit field_author',
    'edit field_awards',
    'edit field_business_name',
    'edit field_campus_id',
    'edit field_career',
    'edit field_certificate',
    'edit field_city',
    'edit field_code',
    'edit field_conclusion',
    'edit field_contact_person',
    'edit field_coreq',
    'edit field_country',
    'edit field_course_id',
    'edit field_credits',
    'edit field_dateofbirth',
    'edit field_dateofdeath',
    'edit field_duration',
    'edit field_edition',
    'edit field_email',
    'edit field_end_date',
    'edit field_entry_mode',
    'edit field_evaluation',
    'edit field_eventrepeat_date',
    'edit field_fax',
    'edit field_firstname',
    'edit field_floor',
    'edit field_gender',
    'edit field_hall_name',
    'edit field_hall_number',
    'edit field_head',
    'edit field_head_title',
    'edit field_history',
    'edit field_hours',
    'edit field_imprint',
    'edit field_institution',
    'edit field_interests',
    'edit field_introduction',
    'edit field_ip',
    'edit field_isbn_electronic',
    'edit field_isbn_hardback',
    'edit field_isbn_paperback',
    'edit field_issn_electronic',
    'edit field_issn_paperback',
    'edit field_issue',
    'edit field_languages',
    'edit field_lastname',
    'edit field_late_end_date',
    'edit field_lesson_id',
    'edit field_main',
    'edit field_main_section',
    'edit field_marital_status',
    'edit field_marked',
    'edit field_max_score',
    'edit field_methodology',
    'edit field_mobile',
    'edit field_nonreq',
    'edit field_objectives',
    'edit field_parent_section',
    'edit field_percent',
    'edit field_personal_title',
    'edit field_phone',
    'edit field_position',
    'edit field_postbox',
    'edit field_postcode',
    'edit field_prereq',
    'edit field_publication_date',
    'edit field_reason',
    'edit field_remarks',
    'edit field_requirements',
    'edit field_resources',
    'edit field_room',
    'edit field_room_number',
    'edit field_salary',
    'edit field_sample_answer',
    'edit field_score',
    'edit field_seats',
    'edit field_section',
    'edit field_section_id',
    'edit field_start_date',
    'edit field_studentid',
    'edit field_supplement',
    'edit field_term',
    'edit field_url',
    'edit field_volume',
    'view field_marked',
    'view field_sample_answer',
    'view field_score',
    'administer filters',
    'administer menu',
    'administer content types',
    'administer nodes',
    'create book content',
    'create page content',
    'create pe_acad_registration content',
    'create pe_acad_term content',
    'create pe_acad_year content',
    'create pe_assignment_question content',
    'create pe_course content',
    'create pe_edu content',
    'create pe_group content',
    'create pe_group_advisers content',
    'create pe_group_course content',
    'create pe_group_registration content',
    'create pe_lesson_content content',
    'create pe_lesson_event content',
    'create pe_program content',
    'create pe_room content',
    'create pe_section content',
    'create profileedu content',
    'create profileother content',
    'create story content',
    'delete any book content',
    'delete any business content',
    'delete any institution content',
    'delete any page content',
    'delete any pe_acad_registration content',
    'delete any pe_acad_term content',
    'delete any pe_acad_year content',
    'delete any pe_admission content',
    'delete any pe_assignment_answer content',
    'delete any pe_assignment_question content',
    'delete any pe_course content',
    'delete any pe_edu content',
    'delete any pe_group content',
    'delete any pe_group_advisers content',
    'delete any pe_group_course content',
    'delete any pe_group_registration content',
    'delete any pe_lesson_content content',
    'delete any pe_lesson_event content',
    'delete any pe_program content',
    'delete any pe_publication content',
    'delete any pe_room content',
    'delete any pe_section content',
    'delete any profile content',
    'delete any profileedu content',
    'delete any profileeducation content',
    'delete any profilejob content',
    'delete any profilekin content',
    'delete any profileother content',
    'delete any story content',
    'delete revisions',
    'edit any book content',
    'edit any business content',
    'edit any institution content',
    'edit any page content',
    'edit any pe_acad_registration content',
    'edit any pe_acad_term content',
    'edit any pe_acad_year content',
    'edit any pe_admission content',
    'edit any pe_assignment_answer content',
    'edit any pe_assignment_question content',
    'edit any pe_course content',
    'edit any pe_edu content',
    'edit any pe_group content',
    'edit any pe_group_advisers content',
    'edit any pe_group_course content',
    'edit any pe_group_registration content',
    'edit any pe_lesson_content content',
    'edit any pe_lesson_event content',
    'edit any pe_program content',
    'edit any pe_publication content',
    'edit any pe_room content',
    'edit any pe_section content',
    'edit any profile content',
    'edit any profileedu content',
    'edit any profileeducation content',
    'edit any profilejob content',
    'edit any profilekin content',
    'edit any profileother content',
    'edit any story content',
    'administer organic groups',
    'administer url aliases',
    'create url aliases',
    'edit course status',
    'view course registration',
    'view course status',
    'create gapfilling',
    'edit own gapfilling',
    'create multichoice',
    'edit own multichoice',
    'administer quizzes',
    'create quizzes',
    'user results',
    'create poll content',
    'delete any poll content',
    'edit any poll content',
    'access administration pages',
    'access site reports',
    'administer actions',
    'administer files',
    'administer site configuration',
    'access user profiles',
    'administer users',
    'administer views',
    ),

  'secretary' => array(
    'add content to books',
    'create new books',
    'post comments without approval',
    'view field_marked',
    'view field_sample_answer',
    'view field_score',
    'edit field_accepted',
    'edit field_validated',
    'create book content',
    'create page content',
    'create pe_acad_registration content',
    'create pe_acad_term content',
    'create pe_acad_year content',
    'create pe_assignment_question content',
    'create pe_course content',
    'create pe_edu content',
    'create pe_group content',
    'create pe_group_advisers content',
    'create pe_group_course content',
    'create pe_group_registration content',
    'create pe_lesson_content content',
    'create pe_lesson_event content',
    'create pe_program content',
    'create pe_room content',
    'create pe_section content',
    'create profileedu content',
    'create profileother content',
    'create story content',
    'create url aliases',
    'edit course status',
    'view course registration',
    'view course status',
    'create gapfilling',
    'edit own gapfilling',
    'create multichoice',
    'edit own multichoice',
    'create quizzes',
    'user results',
    'create poll content',
    'access user profiles',
    ),
  );
  foreach ($roles as $role => $permissions) {
    $rid = install_add_role($role);
    install_add_permissions($rid, $permissions);
  }

}


/**
 * Import taxonomy vocabularies and terms
 */
function phpedu_profile_import_taxonomy() {
    $path = drupal_get_path('profile', 'phpedu_profile') .'/taxonomy';
    $path .=  '/' . $dir;
    if ($handle = opendir($path)) {    
	    while ($file = readdir($handle)) {
	      if (preg_match('@(.*)\.inc$@', $file)) {
	        $file_path = $path .'/'. $file;
	                install_taxonomy_export_import_from_file($file_path);
	      }
	    }
	}
}


/**
 * Table schema for the world country table
 *
 */
function world_country_schema() {

    $schema['world_country'] = array(
        'fields' => array(
          'Code' => array('type' => 'varchar', 'length' => 3, 'not null' => true, 'default' => ''),
          'Code2' => array('type' => 'varchar', 'length' => 2, 'not null' => true, 'default' => ''),
          'Name' => array('type' => 'varchar', 'length' => 255, 'not null' => true, 'default' => '')
        ),
        'primary key' => array('Code'),
  );

    return $schema;
}

/**
 * Create the world country table and populate it with data
 *
 */
function phpedu_profile_configure_site() {
    // Create table.
  drupal_install_schema('world_country');

    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AFG', 'Afghanistan', 'AF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NLD', 'Netherlands', 'NL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ANT', 'Netherlands Antilles', 'AN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ALB', 'Albania', 'AL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DZA', 'Algeria', 'DZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ASM', 'American Samoa', 'AS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AND', 'Andorra', 'AD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AGO', 'Angola', 'AO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AIA', 'Anguilla', 'AI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ATG', 'Antigua and Barbuda', 'AG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ARE', 'United Arab Emirates', 'AE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ARG', 'Argentina', 'AR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ARM', 'Armenia', 'AM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ABW', 'Aruba', 'AW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AUS', 'Australia', 'AU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AZE', 'Azerbaijan', 'AZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BHS', 'Bahamas', 'BS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BHR', 'Bahrain', 'BH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BGD', 'Bangladesh', 'BD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BRB', 'Barbados', 'BB')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BEL', 'Belgium', 'BE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BLZ', 'Belize', 'BZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BEN', 'Benin', 'BJ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BMU', 'Bermuda', 'BM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BTN', 'Bhutan', 'BT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BOL', 'Bolivia', 'BO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BIH', 'Bosnia and Herzegovina', 'BA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BWA', 'Botswana', 'BW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BRA', 'Brazil', 'BR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GBR', 'United Kingdom', 'GB')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VGB', 'Virgin Islands, British', 'VG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BRN', 'Brunei', 'BN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BGR', 'Bulgaria', 'BG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BFA', 'Burkina Faso', 'BF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BDI', 'Burundi', 'BI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CYM', 'Cayman Islands', 'KY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CHL', 'Chile', 'CL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('COK', 'Cook Islands', 'CK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CRI', 'Costa Rica', 'CR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DJI', 'Djibouti', 'DJ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DMA', 'Dominica', 'DM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DOM', 'Dominican Republic', 'DO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ECU', 'Ecuador', 'EC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('EGY', 'Egypt', 'EG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SLV', 'El Salvador', 'SV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ERI', 'Eritrea', 'ER')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ESP', 'Spain', 'ES')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ZAF', 'South Africa', 'ZA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ETH', 'Ethiopia', 'ET')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FLK', 'Falkland Islands', 'FK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FJI', 'Fiji Islands', 'FJ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PHL', 'Philippines', 'PH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FRO', 'Faroe Islands', 'FO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GAB', 'Gabon', 'GA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GMB', 'Gambia', 'GM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GEO', 'Georgia', 'GE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GHA', 'Ghana', 'GH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GIB', 'Gibraltar', 'GI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GRD', 'Grenada', 'GD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GRL', 'Greenland', 'GL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GLP', 'Guadeloupe', 'GP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GUM', 'Guam', 'GU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GTM', 'Guatemala', 'GT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GIN', 'Guinea', 'GN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GNB', 'Guinea-Bissau', 'GW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GUY', 'Guyana', 'GY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HTI', 'Haiti', 'HT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HND', 'Honduras', 'HN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HKG', 'Hong Kong', 'HK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SJM', 'Svalbard and Jan Mayen', 'SJ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IDN', 'Indonesia', 'ID')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IND', 'India', 'IN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IRQ', 'Iraq', 'IQ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IRN', 'Iran', 'IR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IRL', 'Ireland', 'IE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ISL', 'Iceland', 'IS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ISR', 'Israel', 'IL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ITA', 'Italy', 'IT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TMP', 'East Timor', 'TP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('AUT', 'Austria', 'AT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('JAM', 'Jamaica', 'JM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('JPN', 'Japan', 'JP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('YEM', 'Yemen', 'YE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('JOR', 'Jordan', 'JO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CXR', 'Christmas Island', 'CX')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('YUG', 'Yugoslavia', 'YU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KHM', 'Cambodia', 'KH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CMR', 'Cameroon', 'CM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CAN', 'Canada', 'CA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CPV', 'Cape Verde', 'CV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KAZ', 'Kazakstan', 'KZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KEN', 'Kenya', 'KE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CAF', 'Central African Republic', 'CF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CHN', 'China', 'CN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KGZ', 'Kyrgyzstan', 'KG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KIR', 'Kiribati', 'KI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('COL', 'Colombia', 'CO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('COM', 'Comoros', 'KM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('COG', 'Congo', 'CG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('COD', 'Congo, The Democratic Republic of the', 'CD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CCK', 'Cocos (Keeling) Islands', 'CC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PRK', 'North Korea', 'KP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KOR', 'South Korea', 'KR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GRC', 'Greece', 'GR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HRV', 'Croatia', 'HR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CUB', 'Cuba', 'CU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KWT', 'Kuwait', 'KW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CYP', 'Cyprus', 'CY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LAO', 'Laos', 'LA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LVA', 'Latvia', 'LV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LSO', 'Lesotho', 'LS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LBN', 'Lebanon', 'LB')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LBR', 'Liberia', 'LR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LBY', 'Libyan Arab Jamahiriya', 'LY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LIE', 'Liechtenstein', 'LI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LTU', 'Lithuania', 'LT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LUX', 'Luxembourg', 'LU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ESH', 'Western Sahara', 'EH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MAC', 'Macao', 'MO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MDG', 'Madagascar', 'MG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MKD', 'Macedonia', 'MK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MWI', 'Malawi', 'MW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MDV', 'Maldives', 'MV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MYS', 'Malaysia', 'MY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MLI', 'Mali', 'ML')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MLT', 'Malta', 'MT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MAR', 'Morocco', 'MA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MHL', 'Marshall Islands', 'MH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MTQ', 'Martinique', 'MQ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MRT', 'Mauritania', 'MR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MUS', 'Mauritius', 'MU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MYT', 'Mayotte', 'YT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MEX', 'Mexico', 'MX')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FSM', 'Micronesia, Federated States of', 'FM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MDA', 'Moldova', 'MD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MCO', 'Monaco', 'MC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MNG', 'Mongolia', 'MN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MSR', 'Montserrat', 'MS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MOZ', 'Mozambique', 'MZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MMR', 'Myanmar', 'MM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NAM', 'Namibia', 'NA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NRU', 'Nauru', 'NR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NPL', 'Nepal', 'NP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NIC', 'Nicaragua', 'NI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NER', 'Niger', 'NE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NGA', 'Nigeria', 'NG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NIU', 'Niue', 'NU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NFK', 'Norfolk Island', 'NF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NOR', 'Norway', 'NO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CIV', 'C?te d?Ivoire', 'CI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('OMN', 'Oman', 'OM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PAK', 'Pakistan', 'PK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PLW', 'Palau', 'PW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PAN', 'Panama', 'PA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PNG', 'Papua New Guinea', 'PG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PRY', 'Paraguay', 'PY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PER', 'Peru', 'PE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PCN', 'Pitcairn', 'PN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('MNP', 'Northern Mariana Islands', 'MP')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PRT', 'Portugal', 'PT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PRI', 'Puerto Rico', 'PR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('POL', 'Poland', 'PL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GNQ', 'Equatorial Guinea', 'GQ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('QAT', 'Qatar', 'QA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FRA', 'France', 'FR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('GUF', 'French Guiana', 'GF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PYF', 'French Polynesia', 'PF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('REU', 'R?union', 'RE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ROM', 'Romania', 'RO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('RWA', 'Rwanda', 'RW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SWE', 'Sweden', 'SE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SHN', 'Saint Helena', 'SH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('KNA', 'Saint Kitts and Nevis', 'KN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LCA', 'Saint Lucia', 'LC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VCT', 'Saint Vincent and the Grenadines', 'VC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SPM', 'Saint Pierre and Miquelon', 'PM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DEU', 'Germany', 'DE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SLB', 'Solomon Islands', 'SB')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ZMB', 'Zambia', 'ZM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('WSM', 'Samoa', 'WS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SMR', 'San Marino', 'SM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('STP', 'Sao Tome and Principe', 'ST')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SAU', 'Saudi Arabia', 'SA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SEN', 'Senegal', 'SN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SYC', 'Seychelles', 'SC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SLE', 'Sierra Leone', 'SL')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SGP', 'Singapore', 'SG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SVK', 'Slovakia', 'SK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SVN', 'Slovenia', 'SI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SOM', 'Somalia', 'SO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('LKA', 'Sri Lanka', 'LK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SDN', 'Sudan', 'SD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('FIN', 'Finland', 'FI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SUR', 'Suriname', 'SR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SWZ', 'Swaziland', 'SZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CHE', 'Switzerland', 'CH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SYR', 'Syria', 'SY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TJK', 'Tajikistan', 'TJ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TWN', 'Taiwan', 'TW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TZA', 'Tanzania', 'TZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('DNK', 'Denmark', 'DK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('THA', 'Thailand', 'TH')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TGO', 'Togo', 'TG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TKL', 'Tokelau', 'TK')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TON', 'Tonga', 'TO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TTO', 'Trinidad and Tobago', 'TT')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TCD', 'Chad', 'TD')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('CZE', 'Czech Republic', 'CZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TUN', 'Tunisia', 'TN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TUR', 'Turkey', 'TR')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TKM', 'Turkmenistan', 'TM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TCA', 'Turks and Caicos Islands', 'TC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('TUV', 'Tuvalu', 'TV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('UGA', 'Uganda', 'UG')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('UKR', 'Ukraine', 'UA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HUN', 'Hungary', 'HU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('URY', 'Uruguay', 'UY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NCL', 'New Caledonia', 'NC')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('NZL', 'New Zealand', 'NZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('UZB', 'Uzbekistan', 'UZ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BLR', 'Belarus', 'BY')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('WLF', 'Wallis and Futuna', 'WF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VUT', 'Vanuatu', 'VU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VAT', 'Holy See (Vatican City State)', 'VA')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VEN', 'Venezuela', 'VE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('RUS', 'Russian Federation', 'RU')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VNM', 'Vietnam', 'VN')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('EST', 'Estonia', 'EE')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('USA', 'United States', 'US')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('VIR', 'Virgin Islands, U.S.', 'VI')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ZWE', 'Zimbabwe', 'ZW')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('PSE', 'Palestine', 'PS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ATA', 'Antarctica', 'AQ')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('BVT', 'Bouvet Island', 'BV')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('IOT', 'British Indian Ocean Territory', 'IO')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('SGS', 'South Georgia and the South Sandwich Islands', 'GS')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('HMD', 'Heard Island and McDonald Islands', 'HM')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('ATF', 'French Southern territories', 'TF')");
    db_query("INSERT INTO `world_country` (`Code`, `Name`, `Code2`) VALUES ('UMI', 'United States Minor Outlying Islands', 'UM')");

}


/**
 * Implementation of hook_form_alter().
 *
 * Allows the profile to alter the site-configuration form. This is
 * called through custom invocation, so $form_state is not populated.
 */
function phpedu_profile_form_alter(&$form, $form_state, $form_id) {
  if ($form_id == 'install_configure') {
    // Set default for site name field.
    $form['site_information']['site_name']['#default_value'] = t('phpEdu LMS');
    $form['site_information']['site_mail']['#default_value'] = PHPEDU_DEFAULT_SITE_MAIL .'@'. PHPEDU_DEFAULT_DOMAIN;
    $form['admin_account']['account']['name']['#default_value'] = PHPEDU_DEFAULT_ADMIN_USER;
    $form['admin_account']['account']['mail']['#default_value'] = PHPEDU_DEFAULT_ADMIN_USER .'@'. PHPEDU_DEFAULT_DOMAIN;
  }
}
